'MING MECCA
'WORLD CORE FIRMWARE V 1.07
'WRITTEN BY JORDAN BARTEE FOR SPECIAL STAGE SYSTEMS
'WINTER 2012
'V 1.07 June 22 2013

CON

  _clkmode = xtal1 + pll16x     'Enable external clock at range 4-10 MHz with PLL * 16
  _xinfreq = 5_000_000          'External clock at 5 MHz (* 16 = 80 MHz)
  _stack = 128                  'Reserve some space for display memory / stack

VAR

'COGS~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
long stack [128] 'Stack space for the other cogs / methods

'HEL_GFX Pointers~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
long tile_map_base_ptr_parm
long tile_bitmaps_base_ptr_parm
long tile_palettes_base_ptr_parm
long tile_map_sprite_cntrl_parm
long tile_sprite_tbl_base_ptr_parm
long tile_status_bits_parm


'INTRO~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
byte intro
long color_0, color_1, color_2, color_3
byte color_cycle_1, color_cycle_2, color_cycle_3
word emerald_slow
byte rotate


'SPRITE1~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

'----ADC----
word sprite1_x_adc, sprite1_y_adc
word sprite1_x_adc_old, sprite1_y_adc_old
word adc_y_store
byte sprite1_obj_adc, sprite1_ori_adc
byte rel_flag_x
byte rel_flag_y

'----Position----
long sprite1_x, sprite1_y, sprite1_y_comp
byte sprite1_abs_test_y1
byte sprite1_abs_test_y2
byte sprite1_abs_test_x1
byte sprite1_abs_test_x2
byte rel_pos_r, rel_pos_l, rel_pos_u, rel_pos_d
byte speed1, speed2
byte rel_speed

'----Gravity----
byte mario_mode
byte mario_gate
byte sprite1_fall
byte shake
byte shake_anim
byte fall_rate
byte slow_f, slow_x, slow_y
word slow_count, slow_count_holder
byte count_flag
byte x_wrap
byte reverse_gravity

'----Collision----
byte sprite1_clip
long jump
byte sprite1_cb,sprite1_ct_f
byte sprite1_cr_out, sprite1_cl_out, sprite1_cb_out, sprite1_ct_out
byte sprite1_y_col, sprite1_y_col_stbl
byte sp1_col_tile, sp2_col_tile
byte sp1_clip_gate, sp2_clip_gate
byte sp1_offscreen


'----Graphics----
word sprite1_obj, sprite1_ori


'SPRITE2~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

'----ADC----
word sprite2_x_adc, sprite2_y_adc
byte sprite2_obj_adc, sprite2_ori_adc

'----Position----
long sprite2_x, sprite2_y

'----Collision----
byte sprite2_clip
byte sprite2_cr_out, sprite2_cl_out, sprite2_cb_out, sprite2_ct_out
byte sprite2_abs_test_y1
byte sprite2_abs_test_y2
byte sprite2_abs_test_x1
byte sprite2_abs_test_x2
byte sp2_offscreen


'----Graphics----
word sprite2_obj, sprite2_ori


'TILES~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

'----ADC----
byte map_adc
byte edit_adc
byte edit_adc_old
byte tile1_obj, tile1_ori
byte tile2_obj, tile2_ori
byte tile1_pal_adc, tile2_pal_adc

'----Graphics----
byte tile1_graph, tile2_graph
byte tile1_pal, tile2_pal
byte filler_pal
byte filler_tile

'----Map----
word map_index
byte invert_tile
byte edit_visible
byte edit_index
byte edit_holder
byte state_holder
byte edit_trigger
byte edit_gate
byte trig_delay
byte trig_gate

byte static_count
byte border_tile

'----Glitch----
byte glitch
byte tile_glitch, map_glitch, pal_glitch
byte pal_glitch_gate, map_glitch_gate, tile_glitch_gate
word ran
byte ran_gate
long ran_pal
long ran_map
byte ran_col_count
byte ran_color0, ran_color1, ran_color2, ran_color3
byte ran_lum0, ran_lum1, ran_lum2, ran_lum3
byte ran_chroma0, ran_chroma1, ran_chroma2, ran_chroma3
byte chroma_range


'EDEGE COLLISION~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

byte ss_col_r, ss_col_l, ss_col_t, ss_col_b
long old_map
byte edge_delay_l
byte edge_delay_b
long edge_l_wait
long edge_b_wait
byte map_transition
byte map_transition_delay


'SD CARD~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
long mount
long r
byte pack_section
long ram_addr
long number
long char_count
long reverse_count
long line_count
long asset_count

byte sd_color_temp
byte sd_luma_temp
long sd_color[4]
byte sd_color_count
byte data [18]
byte mask_data[18]
long mask_number
byte load_color
byte load_luma
long scramble_count

byte palette_mode
byte col_mode
byte speed_offset
long no_file1, no_file2


'MISCELLANEOUS~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
byte din_0, din_1, din_2, din_3
byte din_4, din_5, din_6, din_7
byte din_8, din_9, din_10, din_11
byte din_12, din_13, din_14, din_15

byte boot

byte left_abyss
byte right_abyss
byte top_abyss
byte bottom_abyss
OBJ

gfx :             "HEL_GFX_ENGINE_040"                  'Andre' LaMothe's PASM video engine
adc :             "jm_adc0838_ez"                       'Jon McPhalen's ADC scanning and scaling object           '
sdfat :           "fsrw"                                'Tomas Rokicki's FAT16 / FAT32 SD routines
num:              "numbers"                             'Jeff Martin's data / string conversion object
PUB Start
'//////////////////////////////// INITIALIZATION ///////////////////////////////////////////////////

'Initialize variables
intro := 1
col_mode := 0
speed_offset := 0
chroma_range := 3
sprite1_x  := 88                'Start sprite1 in center, used in intro
sprite1_y_col_stbl := 174
sp1_col_tile := 1
sp2_col_tile := 1
shake := 1
fall_rate := 1
tile_glitch_gate := 1
map_glitch_gate := 1
pal_glitch_gate := 1

ran := cnt + 172372371 'Seed for spin's random operator

'Initialize pointers to RAM locations used by HEL GFX
tile_map_base_ptr_parm        := @map_load            'Special map used during SD loading
tile_bitmaps_base_ptr_parm    := @tile_bitmaps
tile_palettes_base_ptr_parm   := @palette
tile_map_sprite_cntrl_parm    := $00_00_02_00           '2 sprites / 16 tile width
tile_sprite_tbl_base_ptr_parm := @sprite_tbl[0]
tile_status_bits_parm         := 0

'Initialize sprites

'Sprite1 (typical Player Character)
sprite_tbl[0] := $00_00_00_01                           'Tell HEL GFX to enable sprite
sprite_tbl[1] := @sprite_bitmap_64                      'Start sprite1 at chaos emerald graphic, used in intro

'Sprite2 (typical Non-Player Character)
sprite_tbl[2] := $00_00_00_01
sprite_tbl[3] := @sprite_bitmaps

'//////////////////////////////// SD CARD ////////////////////////////////////////////////////////

'Launch a COG with HEL GFX, the low-level sprite/tile engine used by the World Core. Video output begins here.
gfx.start(@tile_map_base_ptr_parm)

'Mount the SD card at prop pins 0,1,2,3
mount := \sdfat.mount_explicit(0, 1, 2, 3)

'---------------------------------------------------------------------------------------------------
'----WPACK.TXT----

map_load [98] := $11_20     'Begin drawing the progress bar here. This just flips some palettes around in map_load
map_load [98] := $12_20
map_load [98] := $13_20

no_file1 := sdfat.popen(string("WPACK.TXT"),"r")  'Open WPACK.txt, set no_file flag for later use

'This is the big loop that actually moves all the WorldPack data into prop RAM.
repeat
  r := sdfat.pgetc              'Clock in the next character from the text file

  if (r < 0)                    'Exit SD loop if end of file or no file
    quit

  if r == 35                      'If the character is "#", it means we're in a text/comments area
    repeat                        'Enter a loop to skip through all the descriptive text.
      r := sdfat.pgetc
      if r == 35                  'When we hit another "#", text area is over.
        r := sdfat.pgetc          'Advance another character
        quit                      'Terminate the loop

  'Check for Worldpack section marker, ignore it when found and increment pack_section.
  if r == 47                    'Check if character is a "/"
    repeat                      'If yes, cycle through the characters that make up the section title ("/BOOT LOGO/" etc.)
      r := sdfat.pgetc
      if r == 47                'Until another "/" is reached
        pack_section++          'Increment pack_section to flag that we're moving to a new memory segment
        line_count := 0         'Reset line_count
        asset_count := 0        'Reset asset_count
        quit                    'Exit header loop

    'Cycle through more characters (carriage returns mostly) until we reach the next asset block (marked by [x])
    repeat until r == 91        '"["
      r := sdfat.pgetc

  if r == 91                    'Check if character is a "["
    repeat                      'If yes, cycle through following characters
      r := sdfat.pgetc
      if r == 93                'Until "]" is reached
        r := sdfat.pgetc        'step to next character

        asset_count++           'asset_count keeps track of asset blocks, i.e. sprites, tiles, maps, or palettes.
                                'We increment it for each "[x]" we pass.

        line_count := 0         'line_count is used in sprites, tiles, and maps to mark lines of pixels. We reset
                                'Whenever a new asset block starts.

        reverse_count := 15     'Reverse_count counts individual characters, and is used to assemble the string
                                'at the bottom of the loop that we then convert into useable numbers. It counts
                                'down instead of up so that bits are written in reverse order- this is because
                                'HEL_GFX mirrors sprites and tiles at runtime.

        char_count := 0         'char_count is the same as reverse_count, but counts up. It's used for maps
                                'and palettes, which don't require the mirroring that sprites and tiles do.

        sd_color_count := 0     'sd_color_count counts the 4 colors that get assembled into a complete palette

        quit                    'Exit numbering loop



  if (r == 32)                  'Ignore spaces by clocking in the next character.
    r := sdfat.pgetc

  'The code branches into 5 different sections here, which correspond to the 5 areas of WPACK.TXT (BOOT LOGO,
  'MAPS, TILES, SPRITES, PALETTES). We simply iterate through each section by referencing the pack_section
  'variable, incremented in the code above whenever a "/" marker is encountered. In each section, we move
  'the visual progress bar ahead by 1 tile.

  case pack_section
    'Boot logo
    1:
      map_load [98] := $11_20                  'Increment progress bar
      map_load [98] := $12_20
      map_load [98] := $13_20

      if reverse_count < 0                       'Each data line is 16 characters long
        number := num.FromStr(@data, %00100)   'Convert data string (assembled at bottom of loop) to number using base 4.
        longfill (@sprite_bitmap_64 + (line_count * 4),number,1) 'Copy the number into the correct ram location
        line_count++                                             'Set variable to advance to next line
        bytefill(@data,0,16)           'Fill data string with zeros again.
        reverse_count := 15            'Reset character counter (used in string assembly)
    'Maps
    2:
      map_load [99] := $11_20
      map_load [99] := $12_20
      map_load [99] := $13_20

      if r == 48                               'No reason to use the full number converting object here,
        number := 0                            'So just set number to 0 for "0" and 1 for "1"
      if r == 49
        number := 1

      if char_count > 9                      'Map lines are only 10 digits long
        line_count++
        char_count := 0
        reverse_count := 15

      if (asset_count < 17) and (r > 47)    'Filter out bogus characters for safety and ignore extra maps above 15

        'Write the bytes into memory. HEL GFX uses 16*12 maps, so the map_mask follows suit; this is the
        'reason for line_count moving in 16 byte intervals. asset_count is multiplied by 208 bytes (the size
        'of a map_mask) to offset the whole asset block. Asset block + line + character sum to create the
        'RAM address each byte is written into.

        bytefill(@map_mask_0 + (char_count + (line_count * 16))+((asset_count - 1) * 208),number,1)
        char_count++

    'Tiles
    3:
      map_load [100] := $11_20
      map_load [100] := $12_20
      map_load [100] := $13_20

      if (reverse_count < 0)
        if (line_count < 16 )
          number := num.FromStr(@data, %00100)
          if asset_count < 33                           'No more than 32 tiles
                                'Same structure as map writes above, but lines are 1 long wide and assets are 64 bytes
                                longfill (@tile_0 + (line_count * 4) + ((asset_count - 1) * 64),number,1)
          line_count++

        bytefill(@data,0,16)
        reverse_count:=15

    'Sprites
    4:
      map_load [101] := $11_20
      map_load [101] := $12_20
      map_load [101] := $13_20

      'Unlike tiles, sprites have transparency. HEL GFX uses a dedicated transparency mask per sprite. Rather than
      'make the WorldPack author supply their own masks, we just extract it from their sprite art. The actual
      'extraction is handled along with the main data string at the bottom of the loop. Here we simply do
      'two number conversions and two writes, -1 for the sprite and 1 for the corresponding mask.

      if reverse_count < 0
        if (line_count < 16)
          number := num.FromStr(@data, %00100)
          mask_number := num.FromStr(@mask_data, %00100)
          if asset_count < 33
                                '64-byte Sprite + 64-byte Mask = 128 bytes
                                longfill (@sprite_bitmap_0 + (line_count * 4) + ((asset_count - 1) * 128),number,1)
                                longfill (@sprite_bitmap_mask_0 + (line_count * 4) + ((asset_count - 1) * 128),mask_number,1)
          line_count++

        bytefill(@data,0,16)
        bytefill(@mask_data,0,16)
        reverse_count:=15

    'Palettes
    5:
      map_load [102] := $11_20
      map_load [102] := $12_20
      map_load [102] := $13_20

      'HEL GFX palettes consist of three "parts" per color: color value, chroma bit, and luma value. These values are
      'written as a single byte where bits 7-4 are color, bit 3 is chroma, and bits 2-0 are luma. Four such bytes are
      'formatted into a single long which makes up the four-color palette. This section assembles each color individually
      'before finally summing them into a long which gets written to palette RAM.

      'First we do a string comparison to figure out what color is written in WPACK.TXT, and set sd_color_temp to the
      'corresponding binary value.

      if r == 44                'Wait for string assembly until "," which signals the end of a color entry
        if strcomp(@data, string("BLACK"))
          sd_color_temp := %00000
        if strcomp(@data, string("BLUE1"))
          sd_color_temp := %00001
        if strcomp(@data, string("BLUE2"))
          sd_color_temp := %00011
        if strcomp(@data, string("PURPLE"))
          sd_color_temp := %00101
        if strcomp(@data, string("MAGENTA1"))
          sd_color_temp := %00111
        if strcomp(@data, string("MAGENTA2"))
          sd_color_temp := %01001
        if strcomp(@data, string("RED"))
          sd_color_temp := %01011
        if strcomp(@data, string("ORANGE"))
          sd_color_temp := %01101
        if strcomp(@data, string("BROWN"))
          sd_color_temp := %01111
        if strcomp(@data, string("YELLOW1"))
          sd_color_temp := %10001
        if strcomp(@data, string("YELLOW2"))
          sd_color_temp := %10011
        if strcomp(@data, string("GREEN1"))
          sd_color_temp := %10101
        if strcomp(@data, string("GREEN2"))
          sd_color_temp := %10111
        if strcomp(@data, string("GREEN3"))
          sd_color_temp := %11001
        if strcomp(@data, string("CYAN1"))
          sd_color_temp := %11011
        if strcomp(@data, string("CYAN2"))
          sd_color_temp := %11101
        if strcomp(@data, string("CYAN3"))
          sd_color_temp := %11111

        repeat until r > 47     'Advance through characters until we hit the next data point (a luma value, in this case)
          r := sdfat.pgetc

        'Simple trick to convert the ASCII character into a number without using the full number conversion object
        sd_luma_temp := r - 48

        repeat until r == 10    'Advance through carriage returns (move to next valid data line)
          r := sdfat.pgetc

        'Combine colr and luma into 5-bit number, store in sd_color
        sd_color [sd_color_count] := ((sd_color_temp << 3) | sd_luma_temp)
        sd_color_count++

        'Once all colors (+ their luma values) have been stored, combine into a palette and
        'Write the long into memory
        if sd_color_count > 3
          number := (sd_color[3] << 24) | (sd_color[2] << 16) | (sd_color[1] << 8) | sd_color[0]
          if asset_count < 18
                                longfill (@palette + ((asset_count - 1) * 4),number,1)

          else  'Once all the palettes are written, we're done with WPACK.TXT, so we exit the loop
                                quit

        bytefill(@data,0,16)
        char_count := 0

  'Here's where the actual data string is assembled.
  'First check for real data and omit map section (which doesn't use string) and palette section (which does use reverse_count)
  if (r > 47) and ((pack_section <> 2) and (pack_section <> 5))
    data[reverse_count ] := data[reverse_count] + r            'Send character to string.
    if pack_section == 4                                'Sprite section contains a second string, the sprite mask
      if r == 48                                        'Of the current string character is a "0"
        mask_data[reverse_count] := mask_data[reverse_count] + 48 'Then write a "0" in the mask string
      else
        mask_data[reverse_count] := mask_data[reverse_count] + 51 'If it's anything else, write a "3"
    reverse_count--             'Decrement character counter- stores bits in reverse order to avoid HEL GFX mirroring

  'Unlike tiles and sprites, palettes need bits stored un-mirrored. Char_count is used in place of reverse_count
  if (r > 47) and (pack_section == 5)                   'Check for real data, make sure we're in palette section
    data[char_count ] := data[char_count] + r            'Send character to string.
    char_count++

'Exiting WPACK.TXT loop...
sdfat.pclose                    'Close WPACK.TXT
pack_section := 0               'Reset pack_section and number
number := 0

'---------------------------------------------------------------------------------------------------
'----CONFIG.TXT----

no_file2 := sdfat.popen(string("CONFIG.TXT"),"r")                   'Open CONFIG.txt, set no_file2 flag

'Zork Easter Egg: If no files are present on the card, create two files "HELLO.TXT" and "SAILOR.TXT" with appropriate
'contents. Mount variable is used to make sure there is a card present, so we don't get trapped in a write loop.
if (no_file1 < 0) and (no_file2 < 0) and (mount > -1)
  sdfat.popen(string("HELLO.TXT"),"w")                  'Open HELLOSAILOR.txt
  sdfat.pputs(string("Nothing happ", 13,10 ))
  sdfat.pclose
  sdfat.popen(string("SAILOR.TXT"),"w")                 'Open HELLOSAILOR.txt
  sdfat.pputs(string("ens here.",13,10))
  sdfat.pclose

'If WPACK.TXT was absent, update progress bar to current level. Slow it down a little so viewer can actually see it.
'Don't show it at all if there is no card present.
if no_file1 < 0 and (mount > -1)
  map_load [98] := $13_20
  repeat 4000
  map_load [99] := $13_20
  repeat 4000
  map_load [100] := $13_20
  repeat 4000
  map_load [101] := $13_20
  repeat 4000
  map_load [102] := $13_20
  repeat 40000

'Begin CONFIG.TXT loop
repeat
  map_load [103] := $11_20      'Increment progress bar
  map_load [103] := $12_20
  map_load [103] := $13_20

  r := sdfat.pgetc              'Get first character of CONFIG.TXT
  if (r < 0)                    'Exit SD loop if end of file or no file
    quit

  if r == 32                    'Ignore spaces
    r := sdfat.pgetc

  if r == 35                    'Detect "#", pass over text/comments area
    repeat
      r := sdfat.pgetc
      if r == 35
        quit

  if r == 61                    'Stop at first "=" (means we're at first parameter)
    pack_section++              'Increment section

  if r == 48                    'Set number to 0, 1, or 2 depending on ASCII character
    number := 0
  if r == 49
    number := 1
  if r == 50
    number := 2
  if r == 51
    number := 3
  if r == 52
    number := 4

  'Set variables
  case pack_section
    1:
      intro := number
    2:
      col_mode := number
    3:
      speed_offset := number
    4:
      if number == 0
        chroma_range := 3
      else
        chroma_range := 2
      repeat 20000              'Wait a bit so viewer can see progress bar finish

sdfat.pclose                    'Close CONFIG.TXT
sdfat.unmount                   'Unmount the SD card for safe removal / hot swapping

'//////////////////////////////// BOOT LOGO ////////////////////////////////////////////////////////

'Special Stage chaos emerald descends from the top of the screen while color cycling.
'Once it lands, colors settle and "Special Stage" text is displayed. Emerald graphic
'can be changed to a custom icon when booting from WorldPacks.

'Note: The text is actually onscreen for the entire intro, but it's invisible until
'the emerald lands. The text is just two tiles that initially have all white palettes,
'blending them into the white background. The text reveal is achieved by simply modifying
'the palette used by those two tiles.

repeat
  'Start out with some nice C64-style random color bars
  repeat 72
  palette[19] := (load_color << 4) | 1 << 3 | load_luma
  palette[17] := (load_color << 4) | 1 << 3 | load_luma
  load_color := ||(ran?//16)
  load_luma := ||(ran?//3)+ 4   'Biased in favor of pastels

  scramble_count++
  if scramble_count > 2500
    quit

'Initialize palette 17 and 19 to Intro colors(prevents momentary visual glitch when leaving
'color-bar sequence) and switch to intro map.
palette[19] := (color_3 << 24) | (color_2 << 16) | (color_1 << 8) | %0_111
palette[17] := (color_3 << 24) | (color_2 << 16) | (color_1 << 8) | %0_111
tile_map_base_ptr_parm        := @map_intro

color_cycle_3 := 8              'Initialize color cycling variables. These define the
color_cycle_2 := 15             'relationship of the colors to each other
color_cycle_1 := 3

repeat while intro == 1
  if sprite1_y < 96             'Sprite lands at 96.
    if emerald_slow < 875       'As it falls, emerald_slow slows down the loop
      emerald_slow++            'so its descent is nice and smooth
    else
      sprite1_y++               'When emerald_slow reaches its count, increment Y position
      'Draw the sprite with the correct coordinates
      sprite_tbl[0] := (sprite1_y << 24) + (sprite1_x << 16) + (0 << 8) + ($01)

      if color_cycle_1 < 15     'Color cycle the sprite's palette
        color_cycle_1++         'Color relationships are determined
      else                      'in the INITIALIZATION section, where
        color_cycle_1 := 0      'the color_cycle starting values are set

      if color_cycle_2 < 15
        color_cycle_2++
      else
        color_cycle_2 := 0

      if color_cycle_3 < 15
        color_cycle_3++
      else
        color_cycle_3 := 0

      'Format each color for HEL GFX palettes by converting to byte and adding Chroma/Luma bits
      color_1 := (color_cycle_1 << 4) | %1_000
      color_2 := (color_cycle_2 << 4) | %1_000
      color_3 := (color_cycle_3 << 4) | %1_000

      'Create the palette by bit shifting the three colors into position. First color is
      'manually set to white (background)
      palette[17] := (color_3 << 24) | (color_2 << 16) | (color_1 << 8) | %0_111

      emerald_slow := 0         'reset counter

  'Once sprite has completed its descent (>96), continue color cycling until color_cycle_1 equals 2.
  'Rotate defines how many times it will spin before resting, and also modifies a waitcnt to
  'slow the cycling down as it approaches stasis.

  elseif (color_cycle_1 <> 2) or (rotate < 23)
    if color_cycle_1 < 15
      color_cycle_1++
    else
      color_cycle_1 := 0

    if color_cycle_2 < 15
      color_cycle_2++
    else
      color_cycle_2 := 0

    if color_cycle_3 < 15
      color_cycle_3++
    else
      color_cycle_3 := 0

    color_1 := (color_cycle_1 << 4) | %1_000
    color_2 := (color_cycle_2 << 4) | %1_000
    color_3 := (color_cycle_3 << 4) | %1_000
    palette[17] := (color_3 << 24) | (color_2 << 16) | (color_1 << 8) | %0_111
    repeat 40000                'Overall speed offset, adds to waitcnt
    rotate++
    waitcnt (clkfreq / (96 - (rotate * 3)) + cnt)

  else                          'When cycling stops, change tile palette to reveal "Special Stage" text
    palette[18] := %1000_1_000__1111_1_000__0000_0_101__0000_0_111
    repeat 1000000              'Wait for a few seconds
    sprite1_y  := 25            'Then reset sprite position
    intro := 0                  'and exit intro loop

'//////////////////////////////// LAUNCH REMAINING COGS ////////////////////////////////////////////

'Launch a cog with the CV input method (handles ADC multiplexing, sampling, and scaling)
LaunchCV

'Launch a cog with the TileEdit method (CV editing of map masks)
LaunchTileEdit

'Launch a cog with the MapFill method (draws tile bitmaps and palettes)
LaunchMapFill

'Launch a cog with the EdgeCollision method (screen edge collision output calculation)
LaunchEdgeCollision

'Launch a cog with the DinMultiplex method (scans the digital input multiplexers)
LaunchDinMultiplex

'Tell HEL GFX where in RAM to locate the main map.
tile_map_base_ptr_parm := @map_main

dira[4..6] := %1111111 'Collision outputs

'//////////////////////////////// MAIN LOOP ///////////////////////////////////////////////////////

repeat while 1

  '//////////////////////////////// GLOBAL ////////////////////////////////////////////////////////

  'In order to fix some bugs with x-axis wraparound, we need a flag to tell us
  'when sprite1 is being drawn off the visible edges of the screen.

  if (sprite1_x > 8) and (sprite1_x < 168)
    x_wrap := 0
  else
    x_wrap := 1
    jump := -3                  'Force L/R bounding line height high whenever offscreen -prevents sprite
                                'fall rate from being altered due to illegal bottom collisions during wraparound

  'Set variables to their corresponding digital inputs (scanned by DinMultiplex method running on another cog)

  if boot == 0                  'On first code cycle, wait a little bit so the DinMultiplex cog has time
    repeat 1000                 'to gather the variables, otherwise everything initializes at 0


  rel_pos_u := din_0
  rel_pos_d := din_1
  rel_pos_l := din_2
  rel_pos_r := din_3
  speed1 := din_4
  speed2 := din_5
  sprite1_clip := din_6
  sprite2_clip := din_7
  invert_tile := din_9
  mario_mode := din_8
  edit_visible := din_10
  tile_glitch := din_11
  map_glitch := din_12
  pal_glitch := din_13

  if mario_mode == 1
    reverse_gravity := 1        'Used to fine tune the visual behavior when exiting mario mode -see the
                                'Sprite 1 Absolute Mode section

    if mario_gate == 0          'Bug fix to prevent sprite from disappearing when turning grav on
      if sprite1_y_adc > 206    'Check that the ADC is resting at 0 volts before setting mario_gate
        mario_gate := 1         'Flag is used to prevent CV offset from being applied until adc rests at 0 volts.
                                '(otherwise, turning gravity on while Y CV is non-zero results in immediate offset,
  else                          'causing sprite to disappear in many cases)
    mario_gate := 0



  '//////////////////////////////// SPRITE1 //////////////////////////////////////////////////////////

  'Sprite1 is normally used as the Player Character, and therefore has some extra complexity
  'compared to Sprite2. Each axis may be independently placed under analog (absolute) or
  'digital (relative) control. These modes are automatically handled by the code, and simply
  'assign control to the method most recently used (if a CV change is detected, absolute
  'control is engaged, and if a logical high appears at the corresponding + or - jacks,
  'digital control is engaged). Additionally, there is a special mode entered when
  'the Gravity toggle is turned on referred to as Mario Mode in the comments. This uses a
  'special kind of analog control for the Y-axis that is optimized for platform jumping,
  'and vanilla digital control for the X-axis. Relative Y and Absolute X controls are
  'unresponsive in this mode.

  '---------------------------------------------------------------------------------------------------
  '----Select collision tile----

  'All three modes respond to the clip toggle, but the implementation between them is
  'very different. In this first code block we simply deal with assigning tiles to
  'either "terrain" (sprite may move across it) or "obstacle" (sprite collides with it) states.

  'Clip determines whether the sprite can pass through tiles unimpeded or not. When clip is on,
  'the sprite will respond to collision events and stop moving when it hits the collision tile (col_tile).
  'col_tile may be set to either Tile1 or Tile2 (0 or 1). The code below automatically sets col_tile based
  'on what tile the sprite is on top of when clip is engaged (col_tile is set to the opposite tile).

  'map_transition is also set here -this flag is used to disable relative mode clipping for a few clock
  'cycles when the map is changed. This is to avoid getting stuck in terrain during wrap mode
  'when using the edge_collision outputs to sequence maps for multi-screen composition.

  if old_map == map_index       'Check that map is not changing
    if sprite1_clip == 0
      sp1_clip_gate := 1              'Reset clip gate when collision is off
    else
      if sp1_clip_gate == 1           'Clip gate prevents col_tile from oscillating -we only set it once at
        sp1_clip_gate := 0            'the moment collision is turned on
        if TileBoundTest (-8, -8, sprite1_x, sprite1_y) == 1   'Run TileBound with sprite's center coordinates to test what tile it's on
          sp1_col_tile := 0              'set col_tile to opposite tile of TileBound's result
        else
          sp1_col_tile := 1
  else
    map_transition := 1         'If map is changing, set flag

  if map_transition == 1        'Count a few clock cycles before disabling the flag
     map_transition_delay++
     if map_transition_delay > 10
      map_transition := 0
      map_transition_delay := 0


  '---------------------------------------------------------------------------------------------------
  '----Draw bounding box----

  'Now we create and test bounding boxes using TileBound method. Each call of TileBound takes an X and Y
  'position to define a point. TileBound tests the defined point against quantized tile space for collisions
  'and returns a binary result. By OR'ing two TileBound methods together, a line can be tested. The code
  'below defines four such lines that comprise the bounding box of each sprite. Various collision related
  'flags are set accordingly.

  'Two lines are actually drawn for each side, offset from each other by 1 pixel. Bounding line 1 directly controls the
  'position of the sprite, and so immediately resolves its collision by incrementing or decrementing the sprite position.
  'What we want to do however is register a collision whenever a sprite appears to be "resting" against a tile.
  'This is what the second bounding line does. Even after the primary collision is resolved (and the sprite position
  'has therefore been incremented or decremented to a stable position) the second bounding line will still register
  'a collision, which is then used to set the physical sprite/tile collision output jack high.

  'Additionally, an "offscreen" flag is calculated to determine when the sprite is no longer visible. In absolute mode, this
  'flag is used to kill the S1/T collision output, since the world is bounded in this mode and logically there is nothing but
  'infinite nothingness on all sides beyond the frame of the display (or at least, we don't know what's out there, so the col
  'output shouldn't force an interpretation! Yes, I'm being sort of dumb here). In relative mode however, the world is
  'toroidal, so collision should transfer to the tile on the opposite side of the screen. To achieve this we need to truncate
  'the coordinates used for the offscreen flag so that they overlap a little, otherwise there is a break in the collision output
  'when the sprite wraps from side to side. For this reason two different sets of numbers are used in the offscreen calculations
  'as determined by the "abyss" variables.

  'Bug fix: the "jump" variable is used to adjust the lower edge of the left and right lines. The reason for these adjustments
  'is explained in comments wherever jump is modified.

  '---------------------------------------------------------------------------------------------------
  if rel_flag_y == 1            'Check or relative vs absolute mode and set abyss variables.
    top_abyss := 1
    bottom_abyss := 208
  else
    top_abyss := 2
    bottom_abyss := 208

  if rel_flag_x == 1
    left_abyss := 1
    right_abyss := 175
  else
    left_abyss := 2
    right_abyss := 175

  'Use abyss variables to calculate the offscreen flag.
  if (sprite1_x < left_abyss) or (sprite1_x > right_abyss) or (sprite1_y < top_abyss) or (sprite1_y > bottom_abyss)
    sp1_offscreen := 1
    outa[5] := 0                'We hard kill the collision output here
  else
    sp1_offscreen := 0



  'Left 1
  'TileBound tests the left side of the sprite. sp1_col_tile passes the collision tile
  'to TileBound's tile_test variable.
  if TileBound(-15, jump, sp1_col_tile, sprite1_x, sprite1_y) == 1 or TileBound(-15, -14, sp1_col_tile, sprite1_x, sprite1_y) == 1
    if sprite1_clip == 1        'If clip is engaged, move the sprite in the opposite direction of the obstacle
      sprite1_x++               'In relative mode, this is the primary method of resolving collision
                                'In absolute mode, it is mostly a redundancy for safety


  'Left 2
  if (TileBound(-16, jump, sp1_col_tile, sprite1_x, sprite1_y) == 1 or TileBound(-16, -14, sp1_col_tile, sprite1_x, sprite1_y) == 1) 'second bounding line, offset by 1 pixel on the x-axis
    if sp1_offscreen == 0                     'Only set collision output high if the sprite is onscreen
      outa[5] := 1
    sprite1_cl_out := 1                       'Set physical collision flag high (used later to turn physical output low)
  else
    sprite1_cl_out := 0                       'Set physical collision flag low

  '---------------------------------------------------------------------------------------------------

  'Now we do the same thing for the right side of the sprite. The bounding line is 1 pixel closer to the sprite's center,
  '(creating a slightly asymmetric bounding box) so that the sprite will wiggle a little bit when trapped in spaces that
  'are exactly one tile wide.

  'Right 1
  if TileBound(-2, jump, sp1_col_tile, sprite1_x, sprite1_y) == 1 or TileBound(-2, -14, sp1_col_tile, sprite1_x, sprite1_y) == 1
    if sprite1_clip == 1
      sprite1_x--


  'Right 2
  if (TileBound(-1, jump, sp1_col_tile, sprite1_x, sprite1_y) == 1 or TileBound(-1, -14, sp1_col_tile, sprite1_x, sprite1_y) == 1)
    if sp1_offscreen == 0
      outa[5] := 1
    sprite1_cr_out := 1
  else
    sprite1_cr_out := 0

  '---------------------------------------------------------------------------------------------------

  'Bottom and Top collisions have some additional code due to their important roles in Mario Mode physics (i.e., Gravity toggle = on)

  'Bottom 1
  if TileBound(-2, -1, sp1_col_tile, sprite1_x, sprite1_y) == 1 or TileBound(-14, -1, sp1_col_tile, sprite1_x, sprite1_y) == 1 'The primary bounding line
    adc_y_store := sprite1_y_adc 'Immediately store the current position of the y-axis ADC for later use
    sprite1_cb := 1
    if sprite1_clip == 1
      sprite1_y--
  else
      sprite1_cb := 0

  'Bottom 2 stores the current vertical collision point to be used later in calculating Mario Mode CV offsets.
  'It also modulates the height of the left and right bounding lines so that during the ascending half of a
  'Mario Mode jump, the sprite cannot "slide" on top of a tile and trigger an unwanted bottom-side collision.
  'It also doesn't process collisions if the sprite is off the bottom of the screen (prevents possibility of jumping
  'back up once sprite has fallen in Mario Mode)

  'Bottom 2
  if (TileBound(-2, 0, sp1_col_tile, sprite1_x, sprite1_y) == 1 or TileBound(-14, 0, sp1_col_tile, sprite1_x, sprite1_y) == 1) and sprite1_y < 190 'Only process if sprite is above the bottom of the screen
    sprite1_y_col := (((sprite1_y+15)/16) *16)          'Quantize y-axis position to tile space and store it.
    if sp1_offscreen == 0
      outa[5] := 1
    sprite1_cb_out := 1
    jump := -3                                        'Keep height of L/R lines low
  else
    sprite1_cb_out := 0
    'Only modify jump if gravity is engaged. Also check that sprite is on screen, so that we
    'don't override the forced -2 value set for the off screen state in the GLOBAL section above
    if mario_mode == 1 and x_wrap == 0
      jump := 0                                       'Raise height of L/R lines to avoid registering
    else                                              'collisions while jumping
      jump := -3

  '---------------------------------------------------------------------------------------------------

  'When a sprite's top collides with the bottom of a tile, the ascending slope must be instantly ignored,
  'and control of the sprite transferred to the internal slope completion. For this reason, the top-side
  'collision flag is used as one of the conditions for updating the sprite's y position from the ADC.
  'A bug exists however that allows the sprite to clip through tiles: as the sprite falls, the collision is resolved,
  'which allows control to transfer back to the ADC. The ADC is now incrementally higher than the point of collision.
  'After a few iterations of this, the ADC will "pop" the sprite into a position completely above the tile, thus
  'defeating the collision. ct_f (fall) is therefore used for this purpose instead. ct-f isn't reset to 0 until the ADC
  'explicitly comes to rest at 0 volts.

  'Top 1
  if TileBound(-2, -16, sp1_col_tile, sprite1_x, sprite1_y) == 1 or TileBound(-14, -16, sp1_col_tile, sprite1_x, sprite1_y) == 1
    if sprite1_clip == 1
      sprite1_y++

    sprite1_ct_f :=1


  'Top 2
  if (TileBound(-2, -17, sp1_col_tile, sprite1_x, sprite1_y) == 1 or TileBound(-14, -17, sp1_col_tile, sprite1_x, sprite1_y) == 1)
    sprite1_ct_out := 1
    if sp1_offscreen == 0 'sprite1_y > 2 and sprite1_y < 208 'Bug fix: without this check, sprite always triggers a false collision when wrapping top-to-bottom
      outa[5] := 1
  else
    sprite1_ct_out := 0

  '---------------------------------------------------------------------------------------------------
  '----Toggle physical output----

  'Logical high is set directly in the bounding box code above. Here we
  'set the Sprite1/Tile collision output low only if all bounding lines register no collision
  if (sprite1_cr_out == 0) and (sprite1_cl_out == 0) and (sprite1_ct_out == 0) and (sprite1_cb_out == 0)
    outa[5] := 0

  '------------------------MARIO MODE------------------------------------------------------------------

  'Mario Mode is entered when the Gravity toggle is turned on. It applies dynamic offsets to the sprite1 Y ADC,
  'in effect shifting the "0 volt position" to the height of the last platform collision, thus maintaining
  'consistent jump height no matter where the sprite is on the the screen. To achieve this, the ADC is only
  'allowed to control the sprite position under very specific circumstances.

  'Mario Mode also uses internally generated ramps to complete the analog slope when jumping or walking off
  'platforms involving an offset, since the ADC can't move below the (now elevated) 0 volt point. The speed of
  'these ramps is determined automatically by analyzing the speed of the sprite movement just
  'before it reaches the 0 volt point. This is implemented by simply counting how many pixels it has moved during
  'each iteration of the loop. If it is slower than 1 pixel per loop, we switch to an alternative system that counts
  'how many loop iterations transpire before it moves again.

  'Note: We want to avoid changing the speed of the main loop as much as possible since ramp speed is dependent
  'on it. For this reason the mario_mode flag is used only where necessary to allow or prevent the results of
  'calculations from reaching their variables. Whenever possible the calculations are allowed to continue
  'even if their result isn't currently being used.

  '---------------------------------------------------------------------------------------------------
  '----Count pixels, set gravity ramp speed----

  'The first if-statement determines what region of space to count during. We only want to look at
  'the space just above the current collision offset, so we see how fast the sprite is moving immediately
  'prior to transitioning to the internal gravity ramp. Because the sprite may be moving very fast, we look at a
  'space that is nearly one tile tall. We don't set new rates when the sprite is offscreen because the sprite can
  'hit invisible tiles in the 11th and 13th rows used for wrap. We also don't set rates if the sprite is above a
  'certain region of the screen (< 14), since it frequently causes errors related to the shortened range of motion.

  if (sprite1_y > sprite1_y_col -17) and (sprite1_y < sprite1_y_col - 4) and (sprite1_y > 14) and (x_wrap == 0) and (mario_mode == 1)
    slow_count_holder++                                 'Count number of cycles it takes for sprite to pass through region
    count_flag := 1                                     'Used in the second if statement
    if sprite1_cb_out == 0 and sprite1_ct_f == 0        'Don't update unless sprite is resting on a tile or has hit it's head

      'Compute fall_rate (used by fast slopes) by subtracting the previous Y value from the current one.
      'The + 1 ensures we never get a fall rate of zero (which leads to the sprite often hovering above terrain
      'when the slope fails to complete), and given how gravity works, it looks better if the ramp is slightly faster
      'then the analog slope rather than slightly slower. Sprite1_y_comp ("compare") is set in the DRAW SPRITES section at the end.
      fall_rate := (sprite1_y - sprite1_y_comp) + 2

    fall_rate <#= 11            'Limit the maximum speed, otherwise it's possible to defeat collision and get embedded in terrain

  'The second if statement is for slower slopes, and uses a different counting process. It only looks at a 4 pixel region
  'above the collision point, since it is only used when the sprite is moving slower than 1 pixel per code loop anyway.

  if (sprite1_y => sprite1_y_col - 4) and (sprite1_y > 14) and (x_wrap == 0) and (mario_mode == 1)
    if count_flag == 1                              'Simple gate so we only set slow_count once per jump descent
      if sprite1_cb_out == 0 and sprite1_ct_f == 0  'Only update if descending from a jump (no walking off, no head hit)
        slow_count := (slow_count_holder / 13 )     'Divide number of cycles by number of pixels in first if-statement's
                                                    'region to calculate number of cycles per pixel
      slow_count_holder := 0
      count_flag := 0

  '---------------------------------------------------------------------------------------------------
  '----Apply gravity speed----

  'First, check that there is no active bottom side collision, and that the sprite is on screen.
  'The internally generated gravity ramp can cause problems during wraparound (gets caught between
  'tiles and drops the sprite into the abyss), so we just disable gravity when off screen. Also, if
  'clipping is off then gravity is obviously always active.

  if ((sprite1_cb_out == 0) and (x_wrap == 0)) or (sprite1_clip == 0)
    if slow_count < 2 'This threshold determines when we bridge to incrementing speed instead of slowing it down
      if mario_mode == 1
        sprite1_y := sprite1_y + (fall_rate) 'fall_rate specifies the number of pixels to increase Y by at each cycle
    else
      slow_f++               'count cycles
      if slow_f > slow_count 'only increment Y when the number of cycles specified by slow_count has elapsed
        if mario_mode == 1
          sprite1_y++
        slow_f := 0

    if sprite1_y > sprite1_y_col+1       'Set the fall_flag if the sprite has
      sprite1_fall := 1                             'descended 1 pixels below the collision offset

  '---------------------------------------------------------------------------------------------------
  '----Apply offset----

  if sprite1_y_adc > 206    'Check that the ADC is resting at 0 volts and set some flags
    sprite1_fall := 0
    sprite1_ct_f := 0

    'Now pass the "stable" collision point to the offset calculations below. We only do this at 0 volts
    '(i.e., sprite is resting after the jump), so that the sprite doesn't spontaneously gain height
    'mid-air if a new collision offset is set as it passes tiles during the jump
    sprite1_y_col_stbl := sprite1_y_col

    'We also store the ADC position again (even though this was already done in Bottom 1. I'm not sure why,
    'but sometimes it appears to miss setting it when the sprite lands, resulting in strange non-linearities
    'in the sprite motion. adc_y_store needs to be set both here and in Bottom 1 for smooth operation.)
    adc_y_store := sprite1_y_adc

  else 'if the ADC is not at rest, we now determine whether or not to update sprite1's Y position.
    'Sprite1_y is set only if the following conditions are met:

    '1) The current ADC value is less than what it was at the moment of bottom-side collision
    '   (remember, this is inverted- we are actually checking that the ADC is specifying a value
    '   physically above the collision level)

    '2) There is no bottom-side collision registered by the Bottom 1 bounding line
    '   (prevents clipping into top of tiles during descent)

    '3) There is no top-side collision (prevents sprite clipping through bottom of tiles
    '   during ascent. ct_f is used rather than ct for bug prevention,
    '   see description above in the bounding line section)

    '4) The sprite is not currently falling (prevents "double jumping" during slope completion)

    '5) Mario Mode is engaged

    'If these conditions are met, then we apply the offset to determine the new 0 point for the slope.
    '15 is subtracted from the ADC value to compensate for the 'size of the sprite itself. Then the
    'current bottom collision point is subtracted from the full y-axis range (191) to calculate the offset.
    'The result is maximum bounded by the collision point for safety.

    if mario_gate == 1          'Used to prevent premature offset application when first entering mario_mode - see
                                'comments in digital input section
      if (sprite1_y_adc < adc_y_store) and (sprite1_cb == 0) and (sprite1_ct_f == 0) and (sprite1_fall == 0) and (mario_mode == 1)
        sprite1_y := (sprite1_y_adc - 15) - (191 -(sprite1_y_col_stbl)) <# sprite1_y_col_stbl

      elseif mario_mode == 1      'If sprite1_y is not updated and we are still in mario mode, provide some visual feedback.
        if (sprite1_ct_f == 1 or (sprite1_y_adc < adc_y_store)) 'Check if sprite has hit it's head or is trying to jump
          !shake                  'If either condition is true, shake the sprite around side by side to show it's immobilized.
          if shake == 1
                                shake_anim := 1
          else
                                shake_anim := 0

  sprite1_y #>= 1               'Bound sprite1_y so that it can never wraparound (wrapping ruins collision algorithm)
  sprite1_y <#= 207


  '------------------------ABSOLUTE MODE--------------------------------------------------------------

  'The rel_flag_y and rel_flag_x flags are set in the CV method and RELATIVE MODE sections and are used here to place
  'the sprite's corresponding axis under digital (relative) or analog (absolute) control when Mario Mode is not active.
  'A very simplified form of clipping is applied here, which is the same system used for Sprite2.

  '---------------------------------------------------------------------------------------------------
  '----Y-Axis----

  if (rel_flag_y == 0 and mario_mode == 0)
                                                            'If there's no top/bottom collision, check to see if there
    if ((sprite1_cb_out == 0) and (sprite1_ct_out == 0))    'is a discrepancy betweeen the onscreen sprite position and the
      if sprite1_y + 4 < sprite1_y_adc                      'ADC value of 4 pixels or more (means that sprite was previously
        sprite1_y := sprite1_y + 8                          'clipped while voltage continued to change). The check is
        sprite1_abs_test_y1 := 0                            'performed once for each direction of movement on the axis.
      else                                                  'If there is a discrepancy, increment/decrement the sprite
        sprite1_abs_test_y1 := 1                            'position and set the abs_test flag.

      if sprite1_y - 4 > sprite1_y_adc
        sprite1_y := sprite1_y - 8
        sprite1_abs_test_y2 := 0
      else
        sprite1_abs_test_y2 := 1

      'Now pass control back to the analog input, but only if abs_test is true for both directions of movement.
      'This ensures that the sprite has finished its ramp and caught back up to the current ADC value.
      if (sprite1_abs_test_y1 == 1) and (sprite1_abs_test_y2 == 1)
        sprite1_y := sprite1_y_adc

    else  'If there is a top/bottom collision, then we ignore the ADC
      if (sprite1_cb_out == 1) and (sprite1_ct_out == 0)    'If it's a bottom collision, back the sprite up if the
        if sprite1_y_adc < sprite1_y                        'ADC moves higher than it (otherwise sprite gets
          sprite1_y--                                       'permanently stuck in a collision state even if you
                                                            'move voltage in the opposite direction of the tile)

      if (sprite1_cb_out == 0) and (sprite1_ct_out == 1)    'Same thing for top collision
        if sprite1_y_adc > sprite1_y
          sprite1_y++

  '---------------------------------------------------------------------------------------------------
  '----X-Axis---- (nearly identical to Y-Axis code structurally, only variables change. The one
                                'minor difference is that we allow transfer to abs control during mario mode)


  if rel_flag_x == 0

    if ((sprite1_cl_out == 0) and (sprite1_cr_out == 0))
      if sprite1_x + 4 < sprite1_x_adc
        sprite1_x := sprite1_x + 8
        sprite1_abs_test_x1 := 0
      else
        sprite1_abs_test_x1 := 1

      if sprite1_x - 4 > sprite1_x_adc
        sprite1_x := sprite1_x - 8
        sprite1_abs_test_x2 := 0
      else
        sprite1_abs_test_x2 := 1

      if (sprite1_abs_test_x1 == 1) and (sprite1_abs_test_x2 == 1)
        sprite1_x := sprite1_x_adc

    else
      if (sprite1_cl_out == 1) and (sprite1_cr_out == 0)
        if sprite1_x_adc > sprite1_x
          sprite1_x++

      if (sprite1_cl_out == 0) and (sprite1_cr_out == 1)
        if sprite1_x_adc < sprite1_x
          sprite1_x--


  '---------------------------------------------------------------------------------------------------
  '----No clip----

  'Simply pass control directly to the adc when absolute mode is on and clip is off.

  'The boot variable is used to bypass slewed position update during power cycle -the flag
  'is set after the first iteration of the loop and never returns to zero until the prop is reset. This
  'allows the sprites to be immediately set to the CV present when the module is first turned on.
  'Otherwise you get about half a second of motion when the sprites zip across the screen to their positions,
  'which looks pretty dumb.

  if ((sprite1_clip == 0) or boot == 0) and (mario_mode == 0) and (reverse_gravity == 0)
    if rel_flag_y == 0
      sprite1_y := sprite1_y_adc
    if rel_flag_x == 0
      sprite1_x := sprite1_x_adc

  'Now a little bit of visual tuning- in the event that we're exiting mario mode (indicated by the reverse_gravity flag,
  'set on gravity toggle low), we want the sprite to ramp back up to its position like it does when clipping is engaged,
  'even if clipping is off. This gives a nice feeling of continuity when the sprite returns to a floating state.
  'The code below is copied verbatim from the absolute clipping section, except that the final test includes
  'clearing the reverse_gravity flag, and that it only tests in one direction( if sprite is lower than ADC)

  if (sprite1_clip == 0) and (mario_mode == 0) and (reverse_gravity == 1)
    if sprite1_y - 4 > sprite1_y_adc
      sprite1_y := sprite1_y - 2
      sprite1_abs_test_y2 := 0
    else
      sprite1_abs_test_y2 := 1

    if (sprite1_abs_test_y1 == 1) and (sprite1_abs_test_y2 == 1)
      sprite1_y := sprite1_y_adc
      reverse_gravity := 0



  '------------------------RELATIVE MODE--------------------------------------------------------------

  'Increment / Decrement Sprite1 X/Y position in response to X+, X-, Y+, and Y- digital
  'inputs. The speed of movement is determined by the rel_speed variable. rel_flag and
  'wraparound are also computed here.

  'On the X-Axis, 0-15 and 160 -176 position the sprite offscreen.
  'On the Y-Axis, it's 0-15 and 192-208.
  if (speed1 == 0) and (speed2 == 0)
    rel_speed:= 2

  if speed1 == 1
    rel_speed := 0

  if speed2 == 1
    if speed_offset == 0
      rel_speed := 4
    else
      rel_speed := 24


  '----Right----
  if rel_pos_r == 1
    rel_flag_x := 1
    'If no collision, no clip, and no map change, increment X
    if (sprite1_cr_out == 0) or (sprite1_clip == 0) or (map_transition == 1)
      slow_x++                                          'Simple counter to change speed
      if slow_x > rel_speed                             'Get count max from rel_speed variable
        sprite1_x++
        slow_x := 0

    if sprite1_x => 175         'Process wraparound. Must be => and not >, or sprite
      sprite1_x := 1            'gets trapped offscreen

  '----Left----
  if rel_pos_l == 1
    rel_flag_x := 1
    if (sprite1_cl_out == 0) or (sprite1_clip == 0) or (map_transition == 1)
      slow_x++
      if slow_x > rel_speed
        sprite1_x--
        slow_x := 0
    if sprite1_x =< 1
      sprite1_x := 175

  '----Up----
  if rel_pos_u == 1 and mario_mode == 0
    rel_flag_y := 1
    if (sprite1_ct_out == 0) or (sprite1_clip == 0) or (map_transition == 1)
      slow_y++
      if slow_y > rel_speed
        sprite1_y--
        slow_y := 0
    if sprite1_y =< 1
      sprite1_y := 207

  '----Down----
  if rel_pos_d == 1 and mario_mode == 0
    rel_flag_y := 1
    if (sprite1_cb_out == 0) or (sprite1_clip == 0)  or (map_transition == 1)
      slow_y++
      if slow_y > rel_speed
        sprite1_y++
        slow_y := 0
    if sprite1_y => 207
      sprite1_y := 1

  '------------------------SPRITE1 GRAPHICS-----------------------------------------------------------

  'Set the actual bitmap data for Sprite1 using the Object and Orient controls. We also
  'make the sprite invisible on the extreme vertical edges of the screen, so that the
  'sprite appears to vanish when moving higher or lower than the frame (needed because earlier
  'we bound Y to 1 and 207, leaving a row of pixels visible).

  if sprite1_y == 1 or sprite1_y > 206
    sprite_tbl[3] := @sprite_bitmap_65 'bitmap_65 is filled with all zeroes; completely transparent
  else
    sprite_tbl[3] := @sprite_bitmap_0 + (((sprite1_obj * 4) + sprite1_ori)*128)

  '//////////////////////////////// SPRITE 2 /////////////////////////////////////////////////////////

  '---------------------------------------------------------------------------------------------------
  '----Select collision tile----

  if sprite2_clip == 0
    sp2_clip_gate := 1
  else
    if sp2_clip_gate == 1
      sp2_clip_gate := 0
      if TileBoundTest (-8, -8, sprite2_x, sprite2_y) == 1
        sp2_col_tile := 0
      else
        sp2_col_tile := 1


  if (sprite2_x < 2) or (sprite2_x > 175) or (sprite2_y < 2) or (sprite2_y > 208)
    sp2_offscreen := 1
    outa[6] := 0
  else
    sp2_offscreen := 0

  '---------------------------------------------------------------------------------------------------
  '----Draw bounding box----

  'Left 1

  if TileBound(-15, -2, sp2_col_tile, sprite2_x, sprite2_y) == 1 or TileBound(-15, -14, sp2_col_tile, sprite2_x, sprite2_y) == 1
    if sprite2_clip == 1        'If clip is engaged, move the sprite in the opposite direction of the obstacle
      sprite2_x++               'In relative mode, this is the primary method of resolving collision
                                'In absolute mode, it is mostly a redundancy for safety

  'Left 2
  if (TileBound(-16, -2, sp2_col_tile, sprite2_x, sprite2_y) == 1 or TileBound(-16, -14, sp2_col_tile, sprite2_x, sprite2_y) == 1) 'second bounding line, offset by 1 pixel on the x-axis
    if sp2_offscreen == 0
      outa[6] := 1
    sprite2_cl_out := 1                       'Set physical collision flag high (used later to turn physical output low)
  else
    sprite2_cl_out := 0                       'Set physical collision flag low

  '---------------------------------------------------------------------------------------------------

  'Now we do the same thing for the right side of the sprite. The bounding line is 1 pixel closer to the sprite's center,
  '(creating a slightly asymmetric bounding box) so that the sprite will wiggle a little bit when trapped in spaces that
  'are exactly one tile wide.

  'Right 1
  if TileBound(-2, -2, sp2_col_tile, sprite2_x, sprite2_y) == 1 or TileBound(-2, -14, sp2_col_tile, sprite2_x, sprite2_y) == 1
    if sprite2_clip == 1
      sprite2_x--

  'Right 2
  if (TileBound(-1, -2, sp2_col_tile, sprite2_x, sprite2_y) == 1 or TileBound(-1, -14, sp2_col_tile, sprite2_x, sprite2_y) == 1)
    if sp2_offscreen == 0
      outa[6] := 1
    sprite2_cr_out := 1
  else
    sprite2_cr_out := 0

  '---------------------------------------------------------------------------------------------------


  'Bottom 1
  if TileBound(-2, -1, sp2_col_tile, sprite2_x, sprite2_y) == 1 or TileBound(-14, -1, sp2_col_tile, sprite2_x, sprite2_y) == 1 'The primary bounding line
    if sprite2_clip == 1
      sprite2_y--


  'Bottom 2
  if (TileBound(-2, 0, sp2_col_tile, sprite2_x, sprite2_y) == 1 or TileBound(-14, 0, sp2_col_tile, sprite2_x, sprite2_y) == 1) and sprite2_y < 190 'Only process if sprite is above the bottom of the screen
    if sp2_offscreen == 0
      outa[6] := 1
    sprite2_cb_out := 1
  else
    sprite2_cb_out := 0
    'Only modify jump if gravity is engaged. Also check that sprite is on screen, so that we
    'don't override the forced -2 value set for the off screen state in the GLOBAL section above

  '---------------------------------------------------------------------------------------------------

  'When a sprite's top collides with the bottom of a tile, the ascending slope must be instantly ignored,
  'and control of the sprite transferred to the internal slope completion. For this reason, the top-side
  'collision flag is used as one of the conditions for updating the sprite's y position from the ADC.
  'A bug exists however that allows the sprite to clip through tiles: as the sprite falls, the collision is resolved,
  'which allows control to transfer back to the ADC. The ADC is now incrementally higher than the point of collision.
  'After a few iterations of this, the ADC will "pop" the sprite into a position completely above the tile, thus
  'defeating the collision. ct_f (fall) is therefore used for this purpose instead. ct-f isn't reset to 0 until the ADC
  'explicitly comes to rest at 0 volts.

  'Top 1
  if TileBound(-2, -16, sp2_col_tile, sprite2_x, sprite2_y) == 1 or TileBound(-14, -16, sp2_col_tile, sprite2_x, sprite2_y) == 1
    if sprite2_clip == 1
      sprite2_y++


  'Top 2
  if (TileBound(-2, -17, sp2_col_tile, sprite2_x, sprite2_y) == 1 or TileBound(-14, -17, sp2_col_tile, sprite2_x, sprite2_y) == 1)
    sprite2_ct_out := 1
    if sp2_offscreen == 0
      outa[6] := 1
  else
    sprite2_ct_out := 0

  '---------------------------------------------------------------------------------------------------
  '----Toggle physical output----

  if (sprite2_cr_out == 0) and (sprite2_cl_out == 0) and (sprite2_ct_out == 0) and (sprite2_cb_out == 0)
    outa[6] := 0

  '---------------------------------------------------------------------------------------------------
  '----Y-Axis----

  if ((sprite2_cb_out == 0) and (sprite2_ct_out == 0))
    if sprite2_y + 4 < sprite2_y_adc
      sprite2_y := sprite2_y + 6
      sprite2_abs_test_y1 := 0
    else
      sprite2_abs_test_y1 := 1

    if sprite2_y - 4 > sprite2_y_adc
      sprite2_y := sprite2_y - 6
      sprite2_abs_test_y2 := 0
    else
      sprite2_abs_test_y2 := 1

    if (sprite2_abs_test_y1 == 1) and (sprite2_abs_test_y2 == 1)
      sprite2_y := sprite2_y_adc

  else
    if (sprite2_cb_out == 1) and (sprite2_ct_out == 0)
      if sprite2_y_adc < sprite2_y
        sprite2_y--

    if (sprite2_cb_out == 0) and (sprite2_ct_out == 1)
      if sprite2_y_adc > sprite2_y
        sprite2_y++

  '---------------------------------------------------------------------------------------------------
  '----X-Axis----

  if ((sprite2_cl_out == 0) and (sprite2_cr_out == 0))
    if sprite2_x + 4 < sprite2_x_adc
      sprite2_x := sprite2_x + 6
      sprite2_abs_test_x1 := 0
    else
      sprite2_abs_test_x1 := 1

    if sprite2_x - 4 > sprite2_x_adc
      sprite2_x := sprite2_x - 6
      sprite2_abs_test_x2 := 0
    else
      sprite2_abs_test_x2 := 1

    if (sprite2_abs_test_x1 == 1) and (sprite2_abs_test_x2 == 1)
      sprite2_x := sprite2_x_adc

  else
    if (sprite2_cl_out == 1) and (sprite2_cr_out == 0)
      if sprite2_x_adc > sprite2_x
        sprite2_x++

    if (sprite2_cl_out == 0) and (sprite2_cr_out == 1)
      if sprite2_x_adc < sprite2_x
        sprite2_x--

  '---------------------------------------------------------------------------------------------------
  '----No clip----

  if (sprite2_clip == 0) or boot == 0
    sprite2_y := sprite2_y_adc
    sprite2_x := sprite2_x_adc



  '------------------------SPRITE2 GRAPHICS-----------------------------------------------------------

  if sprite2_y == 1 or sprite2_y > 206
    sprite_tbl[1] := @sprite_bitmap_65 'bitmap_65 is filled with all zeroes; completely transparent
  else
    sprite_tbl[1] := @sprite_bitmap_0 + (((sprite2_obj * 4) + sprite2_ori)*128)

  '------------------------SPRITE/SPRITE COLLISION-----------------------------------------------------

  if ((sprite1_x + 8) => (sprite2_x - 8)) and ((sprite1_x + 8) =< (sprite2_x + 8))
    ss_col_r := 1
  else
    ss_col_r := 0

  if (sprite1_x - 8) =< (sprite2_x + 8) and ((sprite1_x - 8) => (sprite2_x - 8))
    ss_col_l := 1
  else
    ss_col_l := 0

  if (sprite1_y + 8) => (sprite2_y - 8) and ((sprite1_y + 8) =< (sprite2_y + 8))
    ss_col_b := 1
  else
    ss_col_b := 0

  if (sprite1_y - 8) =< (sprite2_y + 8) and ((sprite1_y - 8) => (sprite2_y - 8))
    ss_col_t := 1
  else
    ss_col_t := 0

  if ((ss_col_r == 1) or (ss_col_l == 1)) and ((ss_col_t == 1) or (ss_col_b == 1))
    outa[4] := 1
  else
    outa[4] := 0

  '//////////////////////////////// TILES ////////////////////////////////////////////////////////////

  'The map_index indicates the currently active map mask to the HEL GFX
  'engine, and MapFill, TileBound and TileEdit methods.

  'map_adc := 1
  old_map := map_index
  map_index := map_adc * 208

   '------------------------TILE GRAPHICS-------------------------------------------------------------
  tile1_graph := (tile1_obj * 4) + tile1_ori
  tile2_graph := (tile2_obj * 4) + tile2_ori

  'Glitch functions. Selects a random location in RAM for tiles, maps, and palettes.
  'pointers are scaled so they never access the prop ROM, because I think the character set is ugly.

  if pal_glitch == 1                                'If palette glitching is enabled
    tile_palettes_base_ptr_parm   := @palette[20]   'Switch to secondary set of 17 palettes
    if pal_glitch_gate == 1            'Trigger logic. ran_gate set low at end of if-statement = 1 glitch per gate high

      'Fill secondary set of palettes with random colors
      repeat until ran_col_count > 16
        ran_pal := ||ran?//32768         'Get a random number, scaling it to Propeller RAM

        repeat
          ran_chroma0 := ||(ran?//2)    'Get four random chroma bits
          ran_chroma1 := ||(ran?//2)
          ran_chroma2 := ||(ran?//2)
          ran_chroma3 := ||(ran?//2)

          'If more than 3 chroma bits are high, exit loop. Otherwise, try again for a higher number.
          'This eliminates dark colors that bleed into sync-range and yield garbage screens. Sometimes
          'however we want garbage screens! So choma_range can be set to 2 rather than 3 using config.txt

          if(ran_chroma0 + ran_chroma1 + ran_chroma2 + ran_chroma3) > chroma_range 'Standard value for chroma_range is 3
                                quit

        ran_lum0 := ||(ran?//8)         'Get four random luma values
        ran_lum1 := ||(ran?//8)
        ran_lum2 := ||(ran?//8)
        ran_lum3 := ||(ran?//8)

        'Again, limit garbage screeens with some logic. Here we constrain luma values to a maximum of
        '6 when chroma is enabled.
        if (ran_lum0 > 6) and (ran_chroma0 == 1)
          ran_lum0 := 6
        if (ran_lum1 > 6) and (ran_chroma1 == 1)
          ran_lum1 := 6
        if (ran_lum1 > 6) and (ran_chroma1 == 1)
          ran_lum1 := 6
        if (ran_lum1 > 6) and (ran_chroma1 == 1)
          ran_lum1 := 6

        'Assemble the four colors using ran_pal to index a location of RAM to fill the color nibbles
        ran_color0 := (BYTE [ @ran_pal ] << 4) | ran_chroma0 << 3 | ran_lum0
        ran_color1 := (BYTE [ @ran_pal ] [-4] << 4) | ran_chroma1 << 3 | ran_lum1
        ran_color2 := (BYTE [ @ran_pal ] [-8] << 4) | ran_chroma2 << 3 | ran_lum2
        ran_color3 := (BYTE [ @ran_pal ] [-12] << 4) | ran_chroma3 << 3 | ran_lum3

        'Assemble the full palette, increment to next to palette
        palette [20 + ran_col_count] := (ran_color3<< 24) | (ran_color2 << 16) | (ran_color1 << 8) | ran_color0
        ran_col_count++

      pal_glitch_gate := 0
  else                          'Return everything to normal on gate low
    pal_glitch_gate := 1
    ran_col_count := 0
    tile_palettes_base_ptr_parm   := @palette

  if map_glitch == 1
    if map_glitch_gate == 1
      ran_map := ||(ran?//29440)                        'randomize ran_map, used to index MapFill and TileBound
                                                        'when map glitching is enabled (32768 total ram, minus
                                                        '16 maps * 208 bytes. This ensures we never see Propeller ROM)
      map_glitch_gate := 0
  else
    map_glitch_gate := 1
    ran_map := 0

  if tile_glitch == 1
    if tile_glitch_gate == 1            'Trigger logic. ran_gate set low at end of if-statement = 1 glitch per gate high
      tile_bitmaps_base_ptr_parm    := ||(ran?//30720)  'Point HEL GFX to random location in RAM (32768 total ram, minus
                                                        '32 tiles * 64 bytes. This ensures we never see Propeller ROM
      tile_glitch_gate := 0
  else                          'Return everything to normal on gate low
    tile_glitch_gate := 1
    tile_bitmaps_base_ptr_parm    := @tile_0


  '//////////////////////////////// DRAW SPRITES /////////////////////////////////////////////////////

  'Tell HEL GFX where to draw the sprites (bit shifting is to avoid disturbing the sprite's bitmap pointers)

  'NOTE: y position is offset by 1 pixel (sprite_y + 1) to compensate for a quirk of the collision system that
  'leads to sprites hovering above ground by 1 pixel when clipping is engaged. This just changes how the sprite is drawn,
  'not how the collision logic is processed, so it actually moves the 1 pixel gap to top-side collision instead, which is
  'preferable. A deeper modification of the collision logic itself could remove the problem entirely.

  'Sprite 1
  sprite_tbl[2] := (sprite1_y << 24) + ((sprite1_x + shake_anim) << 16) + (0 << 8) + ($01)
  sprite1_y_comp := sprite1_y

  'Sprite2
  sprite_tbl[0] := (sprite2_y << 24) + (sprite2_x << 16) + (0 << 8) + ($01)

  boot := 1                     'Finally, set boot to 1 to signal that we've gotten through the first cycle of the main loop

PUB LaunchMapFill
'needs about 9 longs of stack space
cognew (MapFill(), @stack[120])

PUB MapFill (i)
'HEL GFX uses map arrays of 16*12 WORDS to draw the screen. Each WORD breaks into two BYTES: The MSB specifies
'the palette, and the LSB specifies the tile. Only 10*12 of these tiles are visible -the remaining 6 tiles
'exist to the right of the screen and are used for smooth scrolling, which Ming Mecca doesn't support.

'In Ming Mecca's implementation, we want to modulate the tiles and palettes without changing the underlying
'map (map_main), so a secondary set of 16 arrays called map_mask_x are used, which is composed of BYTES holding 0
'or 1. While the map_main array has its contents modified to change the graphic or palette settings for Tile1 and
'Tile2, map_mask_x always remains unchanged unless a dynamic tile placement is engaged (see TileEdit method).
'MapFill uses map_mask to determine the Tile1/Tile2 layout, and then performs writes to the map_main array
'to update graphics and palettes.

repeat while 1

  'Iterate through each tile of the currently active map mask and check for Tile1 or Tile2. i is used directly
  'to step through each BYTE of the array, and map_index is added to the base address of map_mask_0
  'to access the correct mask. At each iteration, the graphic and palette for Tile1 and Tile2 is updated.
  'i is multiplied by 2 to step through each WORD of the map_main array, and a simple bitwise operation formats
  'the WORD with palettes and graphics specified by tile1_graph and tile1_pal. A special version is used
  'for glitch mode, an arbitrary full range byte is used instead of the 0/1 values normally used in map_mask.

  repeat until i > 185 'repeat loop using total tilespace (16*12) minus the final 6 offscreen tiles for efficiency

    if map_glitch == 1                             'If map glitching is toggled on
      if BYTE [ran_map + map_index] [ i ] < 127                        'Set threshold for halfway through byte values
        wordfill(@map_main + (i*2), tile1_graph | (tile1_pal << 8),1)
      else
        wordfill(@map_main + (i*2), tile2_graph | (tile2_pal << 8),1)

    else                                                               'If no glitching, enter normal mode
      if BYTE [@map_mask_0 + map_index] [ i ] == 0
        wordfill(@map_main + (i*2), tile1_graph | (tile1_pal << 8),1)
      else
        wordfill(@map_main + (i*2), tile2_graph | (tile2_pal << 8),1)
    i++
  i := 0

PUB LaunchTileEdit
cognew (TileEdit(), @stack[100])

PUB TileEdit (i)

'Tile Edit handles the Dynamic Map Transformation features. A control voltage at jack Index Position sweeps through
'the screen from bottom to top, left-to-right and selects a tile to edit. A trigger at jack Tile Invert then
'switches that position between Tile1 and Tile2. The Highlight toggle provides visible feedback of Index Position
'using a simple palette substitution when activated.

repeat while 1

  '---------------------------------------------------------------------------------------------------
  '----Set variables----

  'Because we want Index Position to sweep through the screen in a specific order not idiomatic to the engine (as
  'well as skip tiles that HEL GFX allocates offscreen), the index order is stored in an array called edit_array.
  'The array is index by edit_adc from 0 - 119. For consist results, we only want to access this array once
  'per loop, so we store the result in edit_holder.
  edit_holder := edit_array [edit_adc]

  'edit_trigger stores the digital input state once per loop.
  edit_trigger:= invert_tile

  '---------------------------------------------------------------------------------------------------
  '----Check tiles----

  'Check the tile currently indexed by edit_holder and set state_holder to the opposite of the result (Tile1
  'becomes Tile2, Tile2 becomes Tile1). We also set filler_pal and filler_tile, used in a visual effect
  'explained below.
  if BYTE [@map_mask_0 + (map_index)] [ edit_holder ] == 1
    state_holder := 0
    filler_pal := tile1_pal
    filler_tile := tile2_graph
  else
    state_holder := 1
    filler_pal := tile2_pal
    filler_tile := tile1_graph

  '---------------------------------------------------------------------------------------------------
  '----Check ADC stillness----

  'static_count is used to see how long the ADC has been still. This is a kind of filtering to ignore very fast
  'slew in the voltage, so that in the case of a sequencer for instance, the transition between steps doesn't
  'spew garbage tiles on the screen.
  if (edit_adc := edit_adc_old) or (edit_adc == 0)
    static_count++
  else
    static_count := 0

  '---------------------------------------------------------------------------------------------------
  '----Trigger logic----

  'The short block of code is a little complex. First we need to convert the raw gate into a trigger,
  'which is achieved using the trig_gate if-statement. However we also want to delay the trigger slightly,
  'since even with static_count doing its job it's still extremely easy to trigger a tile inversion too
  'close to an ADC transition and place tiles where you don't want them. A simple counter is set up using
  'trig_delay that waits for 25 loop iterations before finally setting edit_gate high (as well as resetting
  'trig_gate, so that we don't initiate another trigger event until edit_trigger is first pulled low).

  'Unfortunately this delay can be observed as latency on faster sequences, which breaks the lovely
  'synaesthetic possibilities inherent in the system. To compensate for this we use the filler_tile
  'and filler_pal variables set above to immediately change the tile's graphic on each new trigger event.
  'This only changes the graphic data stored in map_main, not the logical tiles in tile_mask_x, so the changes
  'are immediately overwritten by the MapFill method unless the trigger successfully makes it through the delay
  'and static_count checks to permanently alter the tile in map_mask. Hence the title "filler," as this
  'function literally fills the time between an initial trigger and the final editing of the mask after filtering.

  'As a bonus, we get a nice glicthy flickering while the two cogs (running EditTile and MapFill) battle over
  'which graphic to display. To accentuate this even more, we mismatch the palette and graphic during the
  'initial variable assignment in the Tile Check section. This gives the effect of the tile's colors
  'changing before its graphics, adding some visual interest.

  if edit_trigger == 1
    if trig_gate == 1
      trig_delay++
      if trig_delay > 25
        edit_gate := 1
        trig_delay := 0
        trig_gate := 0
      else
        WORD [@map_main] [ edit_holder ] := filler_tile | (filler_pal << 8)
  else
    trig_gate := 1

  '---------------------------------------------------------------------------------------------------
  '----Highlight----

  'Palette 18 is assigned to the currently indexed tile if Highlight is active.
  if edit_visible == 1
    WORD [@map_main] [edit_holder] := (16 << 8) | ((WORD [@map_main] [edit_holder] & (%0000000011111111)))

  '---------------------------------------------------------------------------------------------------
  '----Edit map mask----

  'if the ADC has been still for over 60 loop iterations (Static_count and the trigger has been delay by 25 (edit_gate),
  'then we finally edit the actual mask with the contents of state_holder, thus inverting the current tile.
  if (static_count > 60)
    if edit_gate == 1
      BYTE [@map_mask_0 + map_index] [ edit_holder ] := state_holder
      edit_gate := 0
    static_count := 0

  '---------------------------------------------------------------------------------------------------
  '----Adjust border tiles----

  'Lastly we need to deal with those pesky offscreen tiles located in the 11th column and 13th row. These tiles are used to "bridge"
  'the sprite position during wraparound (so that collision doesn't defeat sprite movement). These tiles must exactly mirror their
  'duplicates in the 11th column and 12th rows. Rather than perform use a large number of if-statements to selectively copy tiles
  'when they're changed, we just copy the entire column/row every iteration.

  'NOTE: Since glitched maps are dynamically generated from live code (arbitrary ram locations), we can't use this routine for
  'BYTEs indexed using ran_map. This means that wraparound is frequently broken in glitched maps because the random code areas may
  'contain offscreen tiles blocking the sprite -which can't be overwritten, because then we'd be arbitrary modifying code which
  'is obviously a very-bad-thing. Fixing this would requite a complete rewrite of the map/glitch/collision systems which I don't
  'think is really worth it, especially since it's a "glitch" mode anyway. And cosmologically speaking, the behavior is actually
  'strictly correct: there really ARE obstacles beyond the television frame in glitched universes.

  'Copy 10th column to 11th column
  'Start border_tile at the last logical tile of row 1 (tile 10 = 11th column) and increment by 1 row (16 tiles) each iteration.
  'Copy the preceding tile (10th column) by subtracting 1 from the border_tile.

  repeat until i > 12
    border_tile := 10 + (16 * i)
    BYTE [ @map_mask_0 + map_index ] [ border_tile ] := BYTE [ @map_mask_0 + map_index ] [ border_tile - 1 ]
    i++
  i := 0

  'Copy 12th row to 13th row
  'Start border_tile at the first logical tile of row 13 and increment by 1 tile each iteration.
  'Copy the equivalent 12th row tile by subtracting 16 from the border_tile.

  repeat until i > 11
    border_tile := 192 + i
    BYTE [ @map_mask_0 + map_index ] [ border_tile ] := BYTE [ @map_mask_0 + (map_index) ] [ border_tile - 16 ]
    i++
  i:=0

  '---------------------------------------------------------------------------------------------------

  edit_adc_old := edit_adc                  'Store the current index for use in the static_count comparison

PUB LaunchEdgeCollision
cognew (EdgeCollision, @stack[80])

PUB EdgeCollision
dira[7..10] := %1111
repeat while 1

  if col_mode == 0
    'Right
    if sprite1_x >173
      outa[10] := 1
    else
      outa[10] := 0

    'Left
    if sprite1_x <4
      outa[9] := 1
    else
      edge_delay_l := 1

    if edge_delay_l == 1
      edge_l_wait++
      if edge_l_wait > 1000
        edge_l_wait := 0
        edge_delay_l := 0
        outa[9] := 0

    'up
    if sprite1_y < 3
      outa[7] := 1
    else
      outa[7] := 0

    'down
    if sprite1_y > 205
      outa[8] := 1
    else
      edge_delay_b := 1

    if edge_delay_b == 1
      edge_b_wait++
      if edge_b_wait > 1000
        edge_b_wait := 0
        edge_delay_b := 0
        outa[8] := 0

  if col_mode == 1
    if sprite1_cr_out == 1
      outa[10] := 1
    else
      outa[10] := 0

    if sprite1_cl_out == 1
      outa[9] := 1
    else
      outa[9] := 0

    if sprite1_ct_out == 1
      outa[7] := 1
    else
      outa[7] := 0

    if sprite1_cb_out == 1
      outa[8] := 1
    else
      outa[8] := 0

  if col_mode == 2

    if (ss_col_r == 1) and ((ss_col_t == 1) or (ss_col_b == 1))
      outa[10] := 1
    else
      outa[10] := 0


    if (ss_col_l == 1) and ((ss_col_t == 1) or (ss_col_b == 1))
      outa[9] := 1
    else
      outa[9] := 0

    if (ss_col_t == 1) and ((ss_col_r == 1) or (ss_col_l == 1))
      outa[7] := 1
    else
      outa[7] := 0

    if (ss_col_b == 1) and ((ss_col_r == 1) or (ss_col_l == 1))
      outa[8] := 1
    else
      outa[8] := 0

  if col_mode == 3
     'Right
    if sprite1_x >173
      outa[10] := 1
    else
      outa[10] := 0

    'Left
    if sprite1_x <4
      outa[9] := 1
    else
      edge_delay_l := 1

    if edge_delay_l == 1
      edge_l_wait++
      if edge_l_wait > 1000
        edge_l_wait := 0
        edge_delay_l := 0
        outa[9] := 0

    if sprite1_ct_out == 1
      outa[7] := 1
    else
      outa[7] := 0

    if sprite1_cb_out == 1
      outa[8] := 1
    else
      outa[8] := 0

  if col_mode == 4
    if sprite1_cr_out == 1
      outa[10] := 1
    else
      outa[10] := 0

    if sprite1_cl_out == 1
      outa[9] := 1
    else
      outa[9] := 0

   'up
    if sprite1_y < 3
      outa[7] := 1
    else
      outa[7] := 0

    'down
    if sprite1_y > 205
      outa[8] := 1
    else
      edge_delay_b := 1

    if edge_delay_b == 1
      edge_b_wait++
      if edge_b_wait > 1000
        edge_b_wait := 0
        edge_delay_b := 0
        outa[8] := 0


PUB TileBound ( x, y, tile_test, sprite_x, sprite_y )

'TileBound checks sprite position against quantized tilespace for collisions. It tests only a single point at a time, which is
'specified by adding an offset (x, y) to the current sprite position. These values are then summed and used to index the map
'mask, which is then compared against tile_test to detect collision. Quantization occurs by simply dividing the respective
'X/Y values by 16 (pixels per tile), multiplying the Y result by 16 again, and then summing to get the final index value.

'The method splits into two versions- one for glitches, where the map is made up of arbitrary bytes, and one for normal
'operation, where the map is conveniently formatted in binary.

if map_glitch == 1 'If map glitching is toggled on

  'Depending on the state of tile_test, we reverse the comparison from >127 to <127. This is the same
  'as swapping out col_tile directly in the normal mode, but because the Byte is arbitrary (i.e., full range 0-255 rather than
  'just 0 or 1) we can't use tile_Test directly, but must set a threshold instead.
  if tile_test == 1
    if BYTE [ran_map + map_index] [ (((sprite_x + x) / 16) + (((sprite_y + y) / 16) * 16)) ] > 127
      result := 1
    else
      result := 0

  if tile_test == 0
    if BYTE [ran_map + map_index] [ (((sprite_x + x) / 16) + (((sprite_y + y) / 16) * 16)) ] < 127
      result := 1
    else
      result := 0

else  'if no glitching, enter normal mode

  if BYTE [@map_mask_0 + map_index] [ (((sprite_x + x) / 16) + (((sprite_y + y) / 16) * 16)) ] == tile_test
    result := 1
  else
    result := 0



PUB TileBoundTest ( x, y, sprite_x, sprite_y )

'TileBoundTest is almost identical to TileBound. It is used to automatically detect which tile should be the collision tile
'when clip is toggled on/off. It's necessary to decouple this special collision test from the rest of the collisions to avoid
'strange glitches resulting from using col_tile to test collision to set col_tile.

if map_glitch == 1
  if BYTE [ran_map + map_index] [ (((sprite_x + x) / 16) + (((sprite_y + y) / 16) * 16)) ] > 127
    result := 1
  else
    result := 0

else
  if BYTE [@map_mask_0 + map_index] [ (((sprite_x + x) / 16) + (((sprite_y + y) / 16) * 16)) ] == 1
    result := 1
  else
    result := 0

PUB LaunchCV
cognew (CV, @stack[50])

PUB CV

'ADC scanning and scaling using the jm_adc0838_ez object.
'We use no averaging or smoothing since we are dealing with sub 8-bit resolution anyway.

'To correct an issue with the adc scale object, we always scale to one digit higher than we need, and
'then maximum bound by the actual value. This ensures an even spread of values across the full 5V range
'(solves a problem related to value distribution where the final two values would be spaced only about .03V
'apart, even with course quantization of 4 or 8 total states)

dira[12..13] := %11               'Pins 12 and 13 are outputs (CS lines)

repeat while 1
  'Disable ADC chip B
  outa[13] := 1

  'Initialize to ADC chip A (Sprites)
  adc.init(12, 14, 15)

  '---------------------------------------------------------------------------------------------------
  '----Sprite1 X----
  'Sprite position starts at left of sprite. 0 places it at left of screen, offscreen. 16 - 159 are visible locations
  '16 pixels * 10 tiles - 1). Values above 160 start inching the sprite off the bottom of the screen, and at 208
  'the sprite is fully offscreen again.

  sprite1_x_adc := adc.scale(adc.read(0), 0, 177) <# 176

  '---------------------------------------------------------------------------------------------------
  '----Sprite1 Y----
  'Sprite position starts at top of sprite. 0 places it at top of screen, offscreen. 16 - 191 are visible locations
  '16 pixels * 12 tiles - 1). Values above 192 start inching the sprite off the bottom of the screen, and at 208
  'the sprite is fully offscreen again. We also invert the range since HEL GFX positions
  'Y axis top to bottom, but we want sprites to rise as voltage increases.

  sprite1_y_adc := (adc.scale(adc.read(1), 0, 209)- 210) * -1 <# 209

  '---------------------------------------------------------------------------------------------------

  'Set relative flags low (transfer control to absolute analog inputs) if ADC changes. We look for it to
  'increment or decrement by at least 3 values in either direciton to filter out spurious input.
  if (sprite1_x_adc > (sprite1_x_adc_old + 2)) or (sprite1_x_adc < (sprite1_x_adc_old - 2))
    rel_flag_x := 0
  if (sprite1_y_adc > (sprite1_y_adc_old + 2)) or (sprite1_y_adc < (sprite1_y_adc_old - 2))
    rel_flag_y := 0

  sprite1_x_adc_old := sprite1_x_adc                    'Store values for relative flag comparison above
  sprite1_y_adc_old := sprite1_y_adc

  '---------------------------------------------------------------------------------------------------
  '----Sprite2 X----

  sprite2_x_adc := adc.scale(adc.read(2), 0, 177) <# 176

  '---------------------------------------------------------------------------------------------------
  '----Sprite2 Y----

  sprite2_y_adc := (adc.scale(adc.read(3), 0, 209)- 210) * -1 <# 209

  '---------------------------------------------------------------------------------------------------

  '----Sprite1 Object / Orient----

  sprite1_obj := adc.scale(adc.read(4), 0, 8) <# 7
  sprite1_ori := adc.scale(adc.read(5), 0, 4) <# 3
  '---------------------------------------------------------------------------------------------------

  '----Sprite2 Object / Orient----

  sprite2_obj := adc.scale(adc.read(6), 0, 8) <# 7
  sprite2_ori := adc.scale(adc.read(7), 0, 4) <# 3

  '---------------------------------------------------------------------------------------------------

  adc.init(13, 14, 15)

  '----Tile1 Object / Orient----

  tile1_obj := adc.scale(adc.read(0), 0, 8) <# 7
  tile1_ori := adc.scale(adc.read(1), 0, 4) <# 3

  '---------------------------------------------------------------------------------------------------
  '----Tile2 Object / Orient----

  tile2_obj := adc.scale(adc.read(2), 0, 8) <# 7
  tile2_ori := adc.scale(adc.read(3), 0, 4) <# 3

  '---------------------------------------------------------------------------------------------------
  '----Palettes----
  tile1_pal := adc.scale(adc.read(4), 0, 16) <# 15
  tile2_pal := adc.scale(adc.read(5), 0, 16) <# 15
  '---------------------------------------------------------------------------------------------------

  '---------------------------------------------------------------------------------------------------
  '----Map Select----

  map_adc := adc.scale(adc.read(6), 0, 16) <# 15
  '---------------------------------------------------------------------------------------------------
  '----Tile Index----

  edit_adc := adc.scale(adc.read(7), 0, 120) <# 119

PUB LaunchDinMultiplex
cognew (DinMultiplex, @stack[25])
PUB DinMultiplex

'Set prop pins to outputs for controlling multiplexers
dira[31] := 1
dira[30] := 1
dira[27] := 1

Repeat while 1
  'Configure multiplexer A and B for input 0
  outa[31] := 0
  outa[30] := 0
  outa[27] := 0

  'Store state of each output
  if ina[23] == 1
    din_0 := 1
  else
    din_0 := 0
  if ina[11] == 1
    din_8 := 1
  else
    din_8 := 0

  '1
  outa[31] := 1
  outa[30] := 0
  outa[27] := 0

  if ina[23] == 1
    din_1 := 1
  else
    din_1 := 0
  if ina[11] == 1
    din_9 := 1
  else
    din_9 := 0

  '2
  outa[31] := 0
  outa[30] := 1
  outa[27] := 0

  if ina[23] == 1
    din_2 := 1
  else
    din_2 := 0
  if ina[11] == 1
    din_10 := 1
  else
    din_10 := 0

  '3
  outa[31] := 1
  outa[30] := 1
  outa[27] := 0

  if ina[23] == 1
    din_3 := 1
  else
    din_3 := 0
  if ina[11] == 1
    din_11 := 1
  else
    din_11 := 0

  '4
  outa[31] := 0
  outa[30] := 0
  outa[27] := 1

  if ina[23] == 1
    din_4 := 1
  else
    din_4 := 0
  if ina[11] == 1
    din_12 := 1
  else
    din_12 := 0

  '5
  outa[31] := 1
  outa[30] := 0
  outa[27] := 1

  if ina[23] == 1
    din_5 := 1
  else
    din_5 := 0
  if ina[11] == 1
    din_13 := 1
  else
    din_13 := 0

  '6
  outa[31] := 0
  outa[30] := 1
  outa[27] := 1

  if ina[23] == 1
    din_6 := 1
  else
    din_6:= 0
  if ina[11] == 1
    din_14 := 1
  else
    din_14 := 0

  '7
  outa[31] := 1
  outa[30] := 1
  outa[27] := 1

  if ina[23] == 1
    din_7 := 1
  else
    din_7 := 0
  if ina[11] == 1
    din_15 := 1
  else
    din_15 := 0

DAT

tile_maps     'HEL_GFX tile maps, used by the World Core as a sort of screen buffer. Each 2-byte pair represents a tile
              'with format (msb)[palette_index | tile_index](lsb). map_load and map_intro are special maps used during
              'SD boot and the intro logo sequence. Map_main is the main buffer and is constantly being overwritten
              'by the map_masks which store the user selectable 16 maps.

              'HEL_GFX maps are 16 tiles wide, but six of those are drawn off the visible screen and are not
              'used by the World Core.

              ' <---------------------------visible on screen-------------------------------->|<------ to right of screen ---------->|              
              '            0      1      2      3      4      5      6      7      8      9   | 10     11     12     13     14     15

map_load      word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00

map_intro     word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$12_21,$12_22,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$11_20,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00

map_main      word      $00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00
              word      $00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00,$00_00

'The tile masks need an extra column on the right and an extra row on the bottom. These are just duplicates of the 10th column
'and 12th row (constantly copied by TileEdit), and are used to feed the collision functions during wraparound when using the relative
'positional inputs (can think of them as a sort of "bridge" connecting the sides). Without them, wraparound breaks when collision is
'set to tile2. Because TileBound will always detect a collision tile (0) on the immediate edges of the screen.

map_mask_0    byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

map_mask_1    byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    1,1,0,0,0,0,0,0,1,1,0,0,0,0,0,0
              byte    1,1,0,0,0,0,0,0,1,1,0,0,0,0,0,0
              byte    1,1,0,0,0,0,0,0,1,1,0,0,0,0,0,0
              byte    1,1,0,0,0,0,0,0,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

map_mask_2    byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0
              byte    0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0
              byte    0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,0
              byte    0,0,0,1,1,1,1,1,1,0,0,0,0,0,0,0
              byte    0,0,1,1,1,1,1,1,1,0,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

map_mask_3    byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0
              byte    0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0
              byte    0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0
              byte    0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0
              byte    0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0
              byte    0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0
              byte    0,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

map_mask_4    byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

map_mask_5    byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,0,0,0,0,1,1,1,0,0,0,0,0,0
              byte    1,1,1,0,0,0,0,1,1,1,0,0,0,0,0,0
              byte    1,1,1,0,0,0,0,1,1,1,0,0,0,0,0,0
              byte    1,1,1,0,0,0,0,1,1,1,0,0,0,0,0,0
              byte    1,1,1,0,0,0,0,1,1,1,0,0,0,0,0,0
              byte    1,1,1,0,0,0,0,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

map_mask_6    byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,0,0,0,1,1,0,0,0,1,0,0,0,0,0,0
              byte    1,0,0,0,1,1,0,0,0,1,0,0,0,0,0,0
              byte    1,0,0,0,1,1,0,0,0,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

map_mask_7    byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,0,0,0,1,1,0,0,0,1,0,0,0,0,0,0
              byte    1,0,0,0,1,1,0,0,0,1,0,0,0,0,0,0
              byte    1,0,0,0,1,1,0,0,0,1,0,0,0,0,0,0
              byte    1,0,1,1,1,1,1,1,0,1,0,0,0,0,0,0
              byte    1,0,1,1,1,1,1,1,0,1,0,0,0,0,0,0
              byte    1,0,1,1,1,1,1,1,0,1,0,0,0,0,0,0
              byte    1,0,1,1,1,1,1,1,0,1,0,0,0,0,0,0
              byte    1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

map_mask_8    byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,0,0,1,1,1,1,0,0,0,0,0,0
              byte    0,1,1,0,0,0,0,1,1,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0
              byte    1,0,0,1,1,1,1,0,0,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

map_mask_9    byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,0,1,1,1,1,0,0,0,1,0,0,0,0,0,0
              byte    1,0,1,1,1,1,0,0,0,1,0,0,0,0,0,0
              byte    1,0,1,1,1,1,0,0,0,1,0,0,0,0,0,0
              byte    1,0,1,1,1,1,0,0,0,1,0,0,0,0,0,0
              byte    1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

map_mask_10   byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,0,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    1,1,1,1,0,1,1,1,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    1,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    1,1,1,1,1,1,1,1,0,1,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0


map_mask_11   byte    1,1,1,1,0,0,1,1,1,1,0,0,0,0,0,0
              byte    1,0,1,0,0,0,0,1,0,1,0,0,0,0,0,0
              byte    1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0
              byte    1,0,0,0,1,1,0,0,0,1,0,0,0,0,0,0
              byte    1,0,1,0,0,0,0,1,0,1,0,0,0,0,0,0
              byte    0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0
              byte    1,1,1,0,0,0,0,1,1,1,0,0,0,0,0,0
              byte    1,0,0,0,1,1,0,0,0,1,0,0,0,0,0,0
              byte    1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0
              byte    1,0,1,0,0,0,0,1,0,1,0,0,0,0,0,0
              byte    1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0
              byte    1,1,1,1,0,0,1,1,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

map_mask_12   byte    1,1,1,1,1,1,1,1,0,1,0,0,0,0,0,0
              byte    1,0,0,0,1,0,0,0,0,1,0,0,0,0,0,0
              byte    1,0,1,0,0,0,1,1,1,1,0,0,0,0,0,0
              byte    1,0,1,1,1,1,1,0,1,1,0,0,0,0,0,0
              byte    1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0
              byte    1,0,1,1,1,1,0,1,0,1,0,0,0,0,0,0
              byte    1,0,1,0,0,0,0,1,0,1,0,0,0,0,0,0
              byte    1,0,1,0,1,1,1,1,1,1,0,0,0,0,0,0
              byte    1,0,1,0,0,1,0,0,0,1,0,0,0,0,0,0
              byte    1,1,1,1,0,1,1,1,0,1,0,0,0,0,0,0
              byte    1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0
              byte    1,0,1,1,1,1,1,1,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

map_mask_13   byte    1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0
              byte    1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0
              byte    1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0
              byte    1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0
              byte    0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0
              byte    1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0
              byte    1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0
              byte    1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0
              byte    1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

map_mask_14   byte    1,1,0,0,1,1,0,0,1,1,0,0,0,0,0,0
              byte    1,1,0,0,1,1,0,0,1,1,0,0,0,0,0,0
              byte    0,0,1,1,0,0,1,1,0,0,0,0,0,0,0,0
              byte    0,0,1,1,0,0,1,1,0,0,0,0,0,0,0,0
              byte    1,1,0,0,1,1,0,0,1,1,0,0,0,0,0,0
              byte    1,1,0,0,1,1,0,0,1,1,0,0,0,0,0,0
              byte    0,0,1,1,0,0,1,1,0,0,0,0,0,0,0,0
              byte    0,0,1,1,0,0,1,1,0,0,0,0,0,0,0,0
              byte    1,1,0,0,1,1,0,0,1,1,0,0,0,0,0,0
              byte    1,1,0,0,1,1,0,0,1,1,0,0,0,0,0,0
              byte    0,0,1,1,0,0,1,1,0,0,0,0,0,0,0,0
              byte    0,0,1,1,0,0,1,1,0,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0

map_mask_15   byte    0,1,0,1,0,1,0,1,0,1,0,0,0,0,0,0
              byte    1,0,1,0,1,0,1,0,1,0,0,0,0,0,0,0
              byte    0,1,0,1,0,1,0,1,0,1,0,0,0,0,0,0
              byte    1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0
              byte    0,1,0,1,1,1,1,0,0,1,0,0,0,0,0,0
              byte    1,0,0,1,0,0,1,0,1,0,0,0,0,0,0,0
              byte    0,1,0,1,0,0,1,0,0,1,0,0,0,0,0,0
              byte    1,0,0,1,1,1,1,0,1,0,0,0,0,0,0,0
              byte    0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0
              byte    1,0,1,0,1,0,1,0,1,0,0,0,0,0,0,0
              byte    0,1,0,1,0,1,0,1,0,1,0,0,0,0,0,0
              byte    1,0,1,0,1,0,1,0,1,0,0,0,0,0,0,0
              byte    0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0


' /////////////////////////////////////////////////////////////////////////////

tile_bitmaps long       'Tile bitmaps. These appears mirror-reflected because HEL-GFX draws
                        'backwards in order to save a step.

tile_0        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0                       'Blue sky
              long      %%0_2_0_0_0_0_0_0_0_2_0_0_0_0_0_0
              long      %%0_0_0_0_0_3_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_2_2_3_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_1_1_1_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_3_3_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_1_2_2_2_2_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_1_1_1_0_0_0
              long      %%0_0_3_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%1_2_2_2_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_1_1_1_0_0_0_2_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_2_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_3_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_2_2_3_0_0_0_0
              long      %%0_0_0_0_2_0_0_0_0_1_1_1_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_2_0

tile_1        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_2_0_0_0_0_0_0_0_2_0_0
              long      %%0_3_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%2_2_3_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%1_1_1_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_1_2_2_2_2_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_1_1_1_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_3_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_1_2_2_2
              long      %%0_0_0_2_0_0_0_0_0_0_0_0_0_1_1_1
              long      %%0_0_0_0_0_0_0_0_0_2_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_3_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_2_2_3_0_0_0_0_0_0_0_0
              long      %%2_0_0_0_0_1_1_1_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_2_0_0_0_0_0

tile_2        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_2_0_0_0_0_0_0_0_2_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_3_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_2_2_3_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_1_1_1_0
              long      %%0_0_0_3_3_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_1_2_2_2_2_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_1_1_1_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_3_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_1_2_2_2_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_1_1_1_0_0_0_2
              long      %%0_0_0_0_0_2_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_3_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_2_2_3_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_1_1_1_0_0_0_0_0_0_0_0_2_0_0_0
              long      %%0_0_0_0_0_0_2_0_0_0_0_0_0_0_0_0

tile_3        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_2_0_0_0_0_0_0_0_2_0_0
              long      %%0_0_0_0_0_0_0_0_0_3_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_2_2_3_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_1_1_1_0_0_0_0_0
              long      %%3_0_0_0_0_0_0_0_0_0_0_0_0_0_0_3
              long      %%2_2_0_0_0_0_0_0_0_0_0_0_0_1_2_2
              long      %%1_0_0_0_0_0_0_0_0_0_0_0_0_0_1_1
              long      %%0_0_0_0_0_0_3_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_1_2_2_2_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_1_1_1_0_0_0_2_0_0_0_0
              long      %%0_2_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_3_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_2_2_3
              long      %%0_0_0_0_0_0_0_0_2_0_0_0_0_1_1_1
              long      %%0_0_2_0_0_0_0_0_0_0_0_0_0_0_0_0

tile_4        long      %%0_0_0_0_0_0_0_0_3_0_0_0_0_0_0_0                       'Night sky
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_2_0_0_0_3_0_0_0_0_0_0_3_0_0_0
              long      %%2_3_2_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_2_0_0_0_0_0_0_2_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_2_3_2_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_2_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_3_0_0_3_0_0_0_0_0_0_2_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_2_3_2
              long      %%0_3_0_0_0_0_0_0_0_0_0_0_0_0_2_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_3_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

tile_5        long      %%2_3_2_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_2_0_0_0_0_0_0_2_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_2_3_2_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_2_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_3_0_0_3_0_0_0_0_0_0_2_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_2_3_2
              long      %%0_3_0_0_0_0_0_0_0_0_0_0_0_0_2_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_3_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_3_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_2_0_0_0_3_0_0_0_0_0_0_3_0_0_0

tile_6        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_3_0_0_3_0_0_0_0_0_0_2_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_2_3_2
              long      %%0_3_0_0_0_0_0_0_0_0_0_0_0_0_2_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_3_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_3_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_2_0_0_0_3_0_0_0_0_0_0_3_0_0_0
              long      %%2_3_2_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_2_0_0_0_0_0_0_2_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_2_3_2_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_2_0_0_0_0_0_0_0

tile_7        long      %%0_3_0_0_0_0_0_0_0_0_0_0_0_0_2_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_3_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_3_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_2_0_0_0_3_0_0_0_0_0_0_3_0_0_0
              long      %%2_3_2_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_2_0_0_0_0_0_0_2_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_2_3_2_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_2_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_3_0_0_3_0_0_0_0_0_0_2_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_2_3_2

tile_8        long      %%1_1_1_1_1_1_0_0_2_1_0_2_0_1_1_1                       'water
              long      %%1_0_0_1_1_0_0_2_0_1_1_0_2_1_0_1
              long      %%1_1_1_0_1_1_2_1_1_0_1_1_1_1_1_0
              long      %%1_2_1_1_0_1_1_0_1_1_1_1_0_2_1_1
              long      %%1_0_1_3_1_0_0_1_1_0_0_1_1_1_1_1
              long      %%1_1_1_0_2_1_1_1_2_1_2_1_3_1_1_0
              long      %%0_0_1_1_0_0_1_1_1_1_1_1_1_2_1_1
              long      %%2_0_0_1_1_0_1_2_1_1_0_0_1_1_1_1
              long      %%1_2_1_1_1_2_2_1_1_0_1_1_0_1_0_2
              long      %%1_1_2_1_1_1_0_0_0_1_0_1_1_0_2_0
              long      %%0_0_1_0_1_1_1_0_1_1_1_1_1_1_0_1
              long      %%1_1_1_1_1_3_0_1_1_1_1_2_1_1_1_0
              long      %%1_0_1_2_1_0_2_1_0_2_0_0_2_1_1_1
              long      %%1_2_2_1_1_1_0_2_1_0_1_0_0_1_1_1
              long      %%0_1_0_1_0_1_1_1_1_2_1_1_0_1_2_1
              long      %%1_1_1_0_1_0_1_1_1_1_3_1_1_0_1_2

tile_9        long      %%1_1_0_0_1_1_0_2_2_0_0_1_0_1_1_1
              long      %%2_2_3_1_1_2_2_1_1_1_0_0_2_0_0_1
              long      %%1_0_1_2_2_0_0_0_1_2_1_1_1_1_1_1
              long      %%1_2_1_0_1_1_1_1_2_2_3_1_2_2_1_0
              long      %%2_1_1_1_1_0_3_1_1_0_0_2_1_0_3_1
              long      %%1_0_1_2_1_1_1_2_3_0_1_0_0_1_2_2
              long      %%0_0_1_1_0_1_0_0_0_2_1_1_1_1_1_0
              long      %%2_1_1_3_2_1_2_0_0_0_0_2_1_1_0_0
              long      %%1_2_0_0_1_1_1_2_2_1_0_0_2_1_1_2
              long      %%1_1_2_2_1_0_0_0_1_0_1_1_0_2_0_0
              long      %%1_0_1_0_0_1_1_1_0_1_2_1_2_1_2_3
              long      %%1_1_1_1_1_1_0_1_1_0_1_3_0_2_1_0
              long      %%2_2_0_1_1_3_0_1_1_2_1_1_1_1_1_1
              long      %%1_2_2_1_2_1_1_1_0_1_2_2_1_0_0_1
              long      %%0_0_0_0_0_2_2_0_1_1_0_0_0_1_1_2
              long      %%1_0_1_1_2_1_1_2_1_1_2_0_1_0_1_0

tile_10       long      %%2_1_0_2_0_1_1_1_2_1_2_1_1_1_0_0
              long      %%0_1_1_0_2_1_0_1_1_0_0_1_1_0_0_2
              long      %%1_0_1_1_1_1_1_0_1_1_1_0_1_1_2_1
              long      %%1_1_1_1_0_2_2_1_1_2_1_1_0_1_1_0
              long      %%1_0_0_1_1_1_1_2_1_0_1_3_1_0_0_1
              long      %%2_1_2_1_3_1_1_0_2_1_1_0_2_1_1_1
              long      %%1_1_1_1_1_2_2_2_0_0_2_1_0_0_1_1
              long      %%1_1_0_0_1_2_1_1_2_0_0_1_2_0_1_2
              long      %%1_0_1_1_0_1_0_2_1_2_1_1_1_2_2_1
              long      %%0_1_0_2_1_0_1_0_1_1_2_1_1_1_0_2
              long      %%3_0_2_1_1_1_1_1_0_0_1_0_1_1_1_0
              long      %%1_1_1_0_1_0_1_0_1_1_1_1_1_2_0_1
              long      %%0_2_0_1_2_1_0_1_0_0_1_2_1_0_2_1
              long      %%1_0_1_1_1_1_1_1_1_2_2_1_1_1_0_2
              long      %%1_2_1_1_0_1_2_1_0_1_0_1_0_1_1_1
              long      %%1_1_2_1_1_0_1_3_1_1_1_0_1_0_1_1

tile_11       long      %%0_1_1_1_2_2_1_1_1_1_0_0_2_1_0_2
              long      %%2_1_0_1_1_0_2_1_1_0_0_2_0_1_1_0
              long      %%1_1_1_0_1_1_1_0_1_1_2_1_1_0_1_1
              long      %%0_2_1_1_1_2_1_1_0_1_1_0_1_1_1_1
              long      %%1_1_1_1_1_0_1_3_1_0_0_1_1_0_0_1
              long      %%3_1_1_0_1_1_1_0_2_1_1_1_2_1_2_1
              long      %%1_2_2_1_0_0_1_1_0_0_1_1_1_2_1_1
              long      %%1_1_1_2_1_0_0_1_1_0_1_2_1_1_0_0
              long      %%0_1_0_1_0_2_1_1_1_2_2_1_1_0_1_1
              long      %%1_0_1_0_1_1_2_1_2_1_0_0_0_1_0_1
              long      %%1_1_0_1_3_0_1_0_1_1_1_0_1_1_1_1
              long      %%1_1_1_0_1_1_1_1_1_3_0_1_1_1_3_1
              long      %%2_1_1_1_1_0_1_2_1_0_2_1_0_2_0_2
              long      %%0_1_1_1_1_2_2_1_1_1_0_2_1_0_1_0
              long      %%0_1_2_1_0_1_0_1_0_1_1_1_1_2_1_0
              long      %%1_0_1_2_1_1_1_0_1_0_1_1_1_1_3_1

tile_12       long      %%0_2_2_0_0_2_2_0_0_2_2_0_0_2_2_0                       'Lava
              long      %%2_2_0_0_0_0_2_2_2_2_0_0_0_0_2_2
              long      %%2_0_0_0_2_0_0_2_2_0_0_0_2_0_0_2
              long      %%0_0_2_0_0_2_0_0_0_0_2_0_0_2_0_0
              long      %%0_0_0_0_0_0_2_0_0_0_0_0_0_0_2_0
              long      %%2_0_0_1_1_0_0_0_2_0_0_1_1_0_0_0
              long      %%0_0_1_2_2_1_0_0_0_0_1_1_2_1_0_0
              long      %%0_1_2_2_2_2_1_0_0_1_2_2_2_2_1_0
              long      %%1_2_2_0_0_2_2_1_1_2_2_0_0_2_2_1
              long      %%2_2_0_0_0_0_2_2_2_2_0_0_0_0_2_2
              long      %%2_0_0_2_2_0_0_2_2_0_0_2_2_0_0_2
              long      %%0_0_2_1_1_2_0_0_0_0_2_1_1_2_0_0
              long      %%0_2_1_0_0_1_2_0_0_2_1_0_0_1_2_0
              long      %%2_1_0_0_0_0_1_2_2_1_0_0_0_0_1_2
              long      %%1_0_0_2_2_0_0_1_1_0_0_2_2_0_0_1
              long      %%0_0_2_2_2_2_0_0_0_0_2_2_2_2_0_0

tile_13       long      %%0_0_2_0_0_2_0_0_0_0_2_0_0_2_0_0
              long      %%1_0_0_0_2_0_0_1_1_0_0_0_2_0_0_1
              long      %%2_1_0_0_0_0_1_2_2_1_0_0_0_0_1_2
              long      %%2_2_1_0_0_1_2_2_2_2_1_0_0_1_2_2
              long      %%0_2_2_1_1_2_2_0_0_2_2_1_1_2_2_0
              long      %%0_0_2_2_2_2_0_0_0_0_2_2_2_2_0_0
              long      %%2_0_0_2_2_0_0_2_2_0_0_2_2_0_0_2
              long      %%1_2_0_0_0_0_2_1_1_2_0_0_0_0_2_1
              long      %%0_1_2_0_0_2_1_0_0_1_2_0_0_2_1_0
              long      %%0_0_1_2_2_1_0_0_0_0_1_2_2_1_0_0
              long      %%2_0_0_1_1_0_0_2_2_0_0_1_1_0_0_2
              long      %%2_2_0_0_0_0_2_2_2_2_0_0_0_0_2_2
              long      %%0_2_2_0_0_2_2_0_0_2_2_0_0_2_2_0
              long      %%0_0_2_2_2_2_0_0_0_0_2_2_2_2_0_0
              long      %%2_0_0_2_2_0_0_0_2_0_0_2_2_0_0_0
              long      %%0_0_0_0_0_0_2_0_0_0_0_0_0_0_2_0

tile_14       long      %%1_2_2_0_0_2_2_1_1_2_2_0_0_2_2_1
              long      %%2_2_0_0_0_0_2_2_2_2_0_0_0_0_2_2
              long      %%2_0_0_2_2_0_0_2_2_0_0_2_2_0_0_2
              long      %%0_0_2_1_1_2_0_0_0_0_2_1_1_2_0_0
              long      %%0_2_1_0_0_1_2_0_0_2_1_0_0_1_2_0
              long      %%2_1_0_0_0_0_1_2_2_1_0_0_0_0_1_2
              long      %%1_0_0_2_2_0_0_1_1_0_0_2_2_0_0_1
              long      %%0_0_2_2_2_2_0_0_0_0_2_2_2_2_0_0
              long      %%0_2_2_0_0_2_2_0_0_2_2_0_0_2_2_0
              long      %%2_2_0_0_0_0_2_2_2_2_0_0_0_0_2_2
              long      %%2_0_0_0_2_0_0_2_2_0_0_0_2_0_0_2
              long      %%0_0_2_0_0_2_0_0_0_0_2_0_0_2_0_0
              long      %%0_0_0_0_0_0_2_0_0_0_0_0_0_0_2_0
              long      %%2_0_0_1_1_0_0_0_2_0_0_1_1_0_0_0
              long      %%0_0_1_2_2_1_0_0_0_0_1_2_2_1_0_0
              long      %%0_1_2_2_2_2_1_0_0_1_2_2_2_2_1_0

tile_15       long      %%0_1_2_0_0_2_1_0_0_1_2_0_0_2_1_0
              long      %%0_0_1_2_2_1_0_0_0_0_1_2_2_1_0_0
              long      %%2_0_0_1_1_0_0_2_2_0_0_1_1_0_0_2
              long      %%2_2_0_0_0_0_2_2_2_2_0_0_0_0_2_2
              long      %%0_2_2_0_0_2_2_0_0_2_2_0_0_2_2_0
              long      %%0_0_2_2_2_2_0_0_0_0_2_2_2_2_0_0
              long      %%2_0_0_2_2_0_0_0_2_0_0_2_2_0_0_0
              long      %%0_2_0_0_0_0_2_0_0_0_0_0_0_0_2_0
              long      %%0_0_2_0_0_2_0_0_0_0_2_0_0_2_0_0
              long      %%1_0_0_0_2_0_0_1_1_0_0_0_2_0_0_1
              long      %%2_1_0_0_0_0_1_2_2_1_0_0_0_0_1_2
              long      %%2_2_1_0_0_1_2_2_2_2_1_0_0_1_2_2
              long      %%0_2_2_1_1_2_2_0_0_2_2_1_1_2_2_0
              long      %%0_0_2_2_2_2_0_0_0_0_2_2_2_2_0_0
              long      %%2_0_0_2_2_0_0_2_2_0_0_2_2_0_0_2
              long      %%1_2_0_0_0_0_2_1_1_2_0_0_0_0_2_1

tile_16       long      %%0_1_0_1_0_1_0_1_0_0_1_0_1_1_0_1                       'Grass
              long      %%0_1_1_1_0_1_0_1_0_1_1_0_1_1_0_1
              long      %%0_0_1_0_0_1_0_0_0_0_1_1_0_1_0_1
              long      %%1_1_0_0_0_1_0_0_2_0_0_1_0_1_0_0
              long      %%1_1_0_2_0_0_1_0_1_1_0_1_0_0_0_0
              long      %%0_0_0_1_1_0_1_0_1_1_0_1_0_1_0_1
              long      %%0_0_0_1_1_0_1_0_0_1_0_0_0_1_0_1
              long      %%0_2_0_0_1_1_1_1_0_1_1_0_0_1_1_1
              long      %%0_1_0_1_0_1_0_1_0_0_1_0_2_0_1_0
              long      %%1_1_1_0_1_0_0_0_2_0_1_0_1_0_1_0
              long      %%1_1_0_0_1_0_0_1_1_0_1_0_1_0_0_0
              long      %%1_0_0_1_0_1_0_1_1_0_1_0_1_0_2_0
              long      %%1_0_1_1_0_1_0_1_0_0_0_1_1_0_1_0
              long      %%0_0_0_1_0_0_0_1_0_1_0_1_1_0_1_1
              long      %%0_2_0_0_0_2_0_1_0_1_0_1_0_0_0_1
              long      %%0_1_0_1_0_1_0_1_0_1_2_0_1_0_0_1

tile_17       long      %%0_2_1_2_1_2_1_2_0_1_1_1_2_1_1_2
              long      %%2_0_1_2_2_2_1_0_2_0_1_2_2_2_1_0
              long      %%0_2_1_1_2_1_1_2_0_2_1_1_2_1_1_2
              long      %%2_0_1_2_1_2_1_0_2_0_1_2_1_2_1_0
              long      %%0_2_1_1_2_1_1_2_0_1_0_1_2_1_0_2
              long      %%2_1_1_2_1_2_0_0_2_0_1_2_1_1_2_0
              long      %%0_1_0_2_2_1_2_1_0_1_0_1_2_1_0_2
              long      %%2_0_1_1_1_1_0_0_2_0_1_1_2_0_2_1
              long      %%1_1_0_1_2_0_2_0_0_1_0_1_1_2_0_2
              long      %%1_0_1_0_1_2_0_2_1_0_1_0_1_0_2_0
              long      %%1_1_0_1_2_0_2_0_1_1_0_1_1_2_0_2
              long      %%1_0_1_0_1_2_0_2_1_0_1_0_1_0_2_0
              long      %%1_1_0_1_1_0_2_0_1_1_0_1_1_2_0_2
              long      %%1_1_0_0_1_2_0_2_1_0_1_2_1_0_2_0
              long      %%2_1_1_0_1_0_2_1_2_0_1_1_1_1_0_2
              long      %%2_1_1_2_1_1_0_2_2_1_1_2_1_2_0_1

tile_18       long      %%0_0_0_1_0_0_2_0_0_0_0_0_0_0_2_0
              long      %%0_1_1_0_0_2_1_2_0_0_0_0_0_2_1_2
              long      %%1_1_1_0_1_1_1_1_1_0_1_0_1_1_1_1
              long      %%0_0_0_0_0_0_0_0_0_0_1_0_0_0_0_0
              long      %%2_0_0_0_1_0_0_0_0_0_0_0_1_0_0_0
              long      %%1_2_0_0_1_1_0_2_0_2_0_0_1_1_0_2
              long      %%1_1_1_0_1_1_1_1_0_1_1_0_0_1_1_1
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_1_0_0_0_2_0_0_0_1_0_0_0_2_0
              long      %%0_1_1_0_0_2_1_0_0_1_1_1_0_2_1_2
              long      %%0_1_1_0_1_1_1_0_1_1_1_1_0_1_1_1
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%2_0_0_1_1_0_0_0_2_0_0_0_1_0_0_0
              long      %%1_2_0_1_1_1_0_2_1_2_0_1_1_0_0_2
              long      %%1_1_0_1_1_0_0_1_1_1_0_1_1_0_1_1
              long      %%0_0_0_0_0_0_0_0_0_1_0_0_0_0_0_0

tile_19       long      %%0_0_0_1_1_1_1_1_1_1_1_1_1_1_1_0
              long      %%0_0_0_0_1_1_1_1_1_1_1_1_0_1_1_2
              long      %%2_2_2_2_1_1_1_1_1_1_1_1_2_1_1_1
              long      %%1_1_1_1_1_1_1_1_0_0_0_1_1_1_1_1
              long      %%1_1_1_1_0_0_1_1_0_0_2_1_1_1_1_1
              long      %%0_0_1_1_0_0_1_1_2_2_1_1_0_1_0_0
              long      %%1_2_1_1_2_2_1_1_1_1_1_1_2_1_1_0
              long      %%2_1_1_1_1_1_1_0_0_0_0_1_1_1_2_2
              long      %%1_1_0_0_1_1_0_0_0_0_2_1_1_1_1_1
              long      %%1_1_0_0_1_1_2_2_2_2_1_1_1_0_0_1
              long      %%1_1_2_2_1_1_1_1_1_1_1_1_1_2_2_1
              long      %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_1
              long      %%1_1_1_0_0_1_0_0_1_1_1_0_0_0_1_1
              long      %%1_1_1_0_0_1_1_0_1_1_1_2_0_0_0_1
              long      %%1_1_1_2_0_1_0_0_0_1_1_1_2_2_2_1
              long      %%1_1_1_1_2_1_2_2_2_1_1_1_1_1_1_1

tile_20       long      %%1_1_2_1_2_1_2_2_2_1_2_1_2_2_2_0                       'Stone
              long      %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_2_0
              long      %%0_1_1_1_1_1_1_1_1_1_1_1_1_2_2_0
              long      %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_2_0
              long      %%0_1_1_1_1_1_1_1_1_1_1_1_1_1_1_0
              long      %%1_1_1_1_1_1_1_1_1_1_1_1_1_1_1_0
              long      %%0_1_0_1_1_1_1_1_1_1_1_1_1_1_1_0
              long      %%0_0_2_0_0_0_0_0_0_0_0_1_0_0_0_0
              long      %%1_2_1_2_1_2_2_0_1_1_1_1_1_1_2_2
              long      %%1_1_1_1_1_1_2_0_1_1_1_1_1_1_1_1
              long      %%1_1_1_1_1_1_2_0_0_1_1_1_1_1_1_1
              long      %%1_1_1_1_1_1_1_0_1_1_1_1_1_1_1_1
              long      %%1_1_1_1_1_1_2_0_1_1_1_1_1_1_1_1
              long      %%1_1_1_1_1_1_1_0_0_1_1_1_1_1_1_1
              long      %%1_1_1_1_1_1_1_0_1_1_1_1_1_1_1_1
              long      %%0_0_0_1_0_0_0_0_0_1_0_0_0_0_2_0

tile_21       long      %%1_1_1_1_1_1_2_0_1_1_1_1_1_1_2_0
              long      %%1_1_1_1_1_1_1_0_0_1_1_1_1_1_1_0
              long      %%1_1_1_1_1_1_1_0_1_1_1_1_1_1_1_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_1_0_0
              long      %%1_1_2_0_1_1_1_1_1_1_2_0_1_1_1_1
              long      %%1_1_1_0_1_1_1_1_1_1_1_0_0_1_1_1
              long      %%1_1_1_0_1_1_1_1_1_1_1_0_1_1_1_1
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%1_1_1_1_1_1_2_0_1_1_1_1_1_1_2_0
              long      %%0_1_1_1_1_1_1_0_1_1_1_1_1_1_1_0
              long      %%1_1_1_1_1_1_1_0_1_1_1_1_1_1_1_0
              long      %%0_0_0_0_0_0_0_1_0_0_0_0_0_0_0_0
              long      %%1_1_2_0_1_1_1_1_1_1_2_0_1_1_1_1
              long      %%1_1_1_0_0_1_1_1_1_1_1_0_1_1_1_1
              long      %%1_1_1_0_1_1_1_1_1_1_1_0_1_1_1_1
              long      %%0_1_0_0_0_0_0_0_0_0_0_0_0_0_0_0

tile_22       long      %%0_0_0_0_0_0_0_0_0_2_2_2_0_0_0_0
              long      %%0_0_2_2_0_0_0_0_2_2_2_2_2_0_0_0
              long      %%0_2_2_2_2_0_0_0_1_2_1_2_2_2_0_0
              long      %%2_2_2_2_2_2_0_0_1_2_2_2_2_2_0_0
              long      %%1_2_1_2_2_2_0_0_1_1_2_2_1_2_0_0
              long      %%1_2_2_1_2_1_0_0_0_1_1_2_2_1_0_0
              long      %%1_1_2_2_1_0_0_0_0_0_1_1_1_0_0_0
              long      %%0_1_1_1_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_2_2_2_0_0_0_0_2_2_2_2_0
              long      %%0_0_0_2_2_2_2_2_0_0_2_1_2_1_2_2
              long      %%0_0_1_2_2_2_2_2_0_0_1_2_2_2_2_2
              long      %%0_0_1_2_1_2_2_1_0_0_1_1_2_1_2_2
              long      %%0_0_1_1_2_2_1_0_0_0_0_1_1_2_2_1
              long      %%0_0_0_1_1_2_1_0_0_0_0_0_1_1_1_0
              long      %%0_0_0_0_1_1_0_0_0_0_0_0_0_0_0_0

tile_23       long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%2_1_2_2_1_2_0_2_0_1_2_1_2_0_2_0
              long      %%0_0_1_1_1_1_0_0_1_1_1_2_0_0_0_0
              long      %%0_2_1_1_0_1_1_1_2_2_1_0_0_0_2_0
              long      %%0_0_0_1_1_1_2_1_1_0_1_0_1_2_0_0
              long      %%1_0_2_0_0_1_1_2_1_1_0_0_1_1_0_0
              long      %%0_1_1_0_0_0_1_1_2_1_1_0_1_1_2_0
              long      %%0_1_2_2_1_0_0_1_1_0_1_1_0_1_2_0
              long      %%0_0_0_2_2_0_0_1_0_0_1_1_2_1_2_0
              long      %%0_0_0_1_2_1_1_1_0_1_1_1_1_2_0_0
              long      %%0_1_0_1_1_1_2_1_1_0_1_1_1_1_0_0
              long      %%1_0_0_0_1_1_1_1_1_1_0_2_1_2_2_0
              long      %%1_0_2_0_1_1_1_2_1_1_0_1_0_2_2_0
              long      %%0_1_1_1_0_0_1_1_2_1_0_0_0_0_1_0
              long      %%0_0_1_1_1_0_0_1_1_2_1_2_0_0_1_0
              long      %%1_0_0_1_1_1_0_1_1_2_2_1_1_0_1_0

tile_24       long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0                       'Rain
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

tile_25       long      %%3_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_3_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_3_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_3_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_3_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_3_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_3_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_3

tile_26       long      %%0_0_0_0_0_0_0_3_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%3_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_3_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_3_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_3_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_3_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_3_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_3_0_0_0_0_0_0_0_0_0

tile_27       long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_3_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_3_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_3_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_3_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_3_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_3_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_3_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_3_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

tile_28       long      %%2_1_2_1_2_2_1_2_0_1_0_1_2_0_2_1                       'Circuitry
              long      %%3_1_1_1_2_2_1_2_0_1_0_1_2_1_2_2
              long      %%0_1_2_1_0_0_1_2_0_1_0_1_1_1_2_2
              long      %%0_1_0_2_0_0_1_2_2_0_1_2_1_1_0_2
              long      %%0_1_1_1_0_1_1_2_2_0_1_0_1_2_2_2
              long      %%1_3_2_2_2_2_2_2_2_0_1_0_1_2_2_0
              long      %%1_1_2_1_2_1_2_1_1_1_1_0_1_2_1_0
              long      %%2_2_2_1_1_1_1_0_0_1_2_0_1_2_1_2
              long      %%1_2_0_1_0_1_0_1_0_1_2_2_2_0_1_2
              long      %%2_0_0_1_0_1_0_1_2_2_2_2_2_0_1_2
              long      %%2_2_0_1_0_1_0_1_1_1_0_0_1_2_2_2
              long      %%2_1_0_1_2_3_0_1_0_1_2_0_1_2_1_0
              long      %%2_2_0_1_2_2_0_1_2_2_2_0_1_2_2_2
              long      %%1_2_1_1_2_2_0_1_1_1_2_0_1_2_2_1
              long      %%0_2_0_2_2_1_0_2_2_1_2_0_0_1_2_0
              long      %%2_1_2_2_0_1_1_2_0_1_2_1_1_2_2_2

tile_29       long      %%2_1_2_1_2_2_1_2_0_1_0_1_2_0_2_1
              long      %%0_1_1_1_2_2_1_2_0_1_0_1_2_1_2_2
              long      %%0_1_2_1_0_0_1_2_0_1_0_1_1_1_2_2
              long      %%0_1_0_2_0_0_1_2_2_0_1_2_1_1_3_2
              long      %%0_1_1_1_0_1_1_2_2_0_1_0_1_2_2_2
              long      %%1_0_2_2_2_2_2_2_2_0_1_0_1_2_2_0
              long      %%1_1_2_1_2_1_2_1_1_1_1_0_1_2_1_0
              long      %%2_2_2_1_1_1_1_0_0_1_2_0_1_2_1_2
              long      %%1_2_0_1_0_1_0_1_0_1_2_2_2_0_1_2
              long      %%2_3_0_1_0_1_0_1_2_2_2_2_2_0_1_2
              long      %%2_2_0_1_0_1_0_1_1_1_0_0_1_2_2_2
              long      %%2_1_0_1_2_3_0_1_0_1_2_0_1_2_1_0
              long      %%2_2_0_1_2_2_0_1_2_2_2_0_1_2_2_2
              long      %%1_2_1_1_2_2_0_1_1_1_2_0_1_2_2_1
              long      %%0_2_0_2_2_1_0_2_2_1_2_0_0_1_2_0
              long      %%2_1_2_2_0_1_1_2_0_1_2_1_1_2_2_2

tile_30       long      %%2_1_2_1_2_2_1_2_0_1_0_1_2_0_2_1
              long      %%0_1_1_1_2_2_1_2_0_1_0_1_2_1_2_2
              long      %%0_1_2_1_0_0_1_2_0_1_0_1_1_1_2_2
              long      %%0_1_0_2_0_0_1_2_2_0_1_2_1_1_0_2
              long      %%0_1_1_1_0_1_1_2_2_0_1_0_1_2_2_2
              long      %%1_0_2_2_2_2_2_2_2_0_1_0_1_2_2_0
              long      %%1_1_2_1_2_1_2_1_1_1_1_0_1_2_1_0
              long      %%2_2_2_1_1_1_1_0_0_1_2_0_1_2_1_2
              long      %%1_2_0_1_0_1_0_1_0_1_2_2_2_0_1_2
              long      %%2_3_0_1_0_1_0_1_2_2_2_2_2_0_1_2
              long      %%2_2_0_1_0_1_0_1_1_1_3_0_1_2_2_2
              long      %%2_1_0_1_2_0_0_1_0_1_2_0_1_2_1_0
              long      %%2_2_0_1_2_2_0_1_2_2_2_0_1_2_2_2
              long      %%1_2_1_1_2_2_0_1_1_1_2_0_1_2_2_1
              long      %%0_2_0_2_2_1_0_2_2_1_2_0_0_1_2_0
              long      %%2_1_2_2_0_1_1_2_0_1_2_1_1_2_2_2

tile_31       long      %%2_1_2_1_2_2_1_2_0_1_0_1_2_0_2_1
              long      %%3_1_1_1_2_2_1_2_0_1_0_1_2_1_2_2
              long      %%0_1_2_1_0_0_1_2_0_1_0_1_1_1_2_2
              long      %%0_1_0_2_0_0_1_2_2_0_1_2_1_1_0_2
              long      %%0_1_1_1_0_1_1_2_2_0_1_0_1_2_2_2
              long      %%1_0_2_2_2_2_2_2_2_0_1_0_1_2_2_0
              long      %%1_1_2_1_2_1_2_1_1_1_1_0_1_2_1_0
              long      %%2_2_2_1_1_1_1_0_0_1_2_0_1_2_1_2
              long      %%1_2_0_1_0_1_0_1_0_1_2_2_2_0_1_2
              long      %%2_0_0_1_0_1_0_1_2_2_2_2_2_0_1_2
              long      %%2_2_0_1_0_1_0_1_1_1_3_0_1_2_2_2
              long      %%2_1_0_1_2_0_0_1_0_1_2_0_1_2_1_0
              long      %%2_2_0_1_2_2_0_1_2_2_2_0_1_2_2_2
              long      %%1_2_1_1_2_2_0_1_1_1_2_0_1_2_2_1
              long      %%0_2_0_2_2_1_0_2_2_1_2_0_0_1_2_0
              long      %%2_1_2_2_0_1_1_2_0_1_2_1_1_2_2_2

tile_64       long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

tile_65       long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_1_1_0_0_1_1_0_1_1_0_0_0_0_0_0
              long      %%0_0_1_0_1_0_1_0_0_0_1_0_0_0_0_0
              long      %%0_1_1_0_0_1_1_0_0_1_0_0_0_0_0_0
              long      %%0_0_1_0_0_0_1_0_1_0_0_0_0_0_0_0
              long      %%0_1_1_0_0_0_1_0_0_1_1_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_1_1_1_0_1_1_0_0_0_0_0_0_0_0
              long      %%1_0_0_1_0_0_0_0_1_0_0_0_0_0_0_0
              long      %%1_0_0_1_0_0_0_1_0_0_0_0_0_0_0_0
              long      %%1_0_0_1_0_0_1_0_0_0_0_0_0_0_0_0
              long      %%1_0_0_1_0_0_0_1_1_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

tile_66       long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_1_0_0_1_0_0_1_0_1_0
              long      %%0_0_0_0_0_0_1_0_1_0_1_0_1_0_0_1
              long      %%0_0_0_0_0_0_1_0_1_1_1_0_1_0_0_1
              long      %%0_0_0_0_0_0_1_0_1_0_1_0_1_0_0_1
              long      %%0_0_0_0_0_1_1_0_1_0_1_0_1_0_1_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_1_1_0_1_1_0_0_0_1
              long      %%0_0_0_0_0_0_0_0_1_0_0_0_1_0_1_0
              long      %%0_0_0_0_0_0_0_1_1_0_0_0_1_0_1_1
              long      %%0_0_0_0_0_0_0_0_1_0_1_0_1_0_1_0
              long      %%0_0_0_0_0_0_0_1_1_0_1_1_0_0_1_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
              long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0


' /////////////////////////////////////////////////////////////////////////////

              'sprite_tbl header, used to control sprite states in HEL_GFX

              ' sprite 0 header
sprite_tbl    long $00_00_00_00  ' state/control word: y,x,z,state, enabled, x=$50, y=$60
              long $00_00_00_00  ' bitmap ptr

              ' sprite 1 header
              long $00_00_00_00  ' state/control word: y,x,z,state
              long $00_00_00_00  ' bitmap ptr


sprite_bitmaps          long    'Sprite bitmaps, once again mirrored. Sprites appear
                                'with an additional bitmap to handle transparency masking.
                                'Each sprite and its mask must be contiguous in memory.

sprite_bitmap_0         long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0             'Digiman
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_1_1_1_3_3_1_1_1_3_3_0_0
                        long      %%0_3_3_3_1_1_1_3_3_1_1_1_3_3_3_0
                        long      %%0_3_3_3_1_1_1_3_3_1_1_1_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0

sprite_bitmap_mask_0    long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0

sprite_bitmap_1         long      %%0_0_0_0_3_0_3_0_3_0_3_0_0_0_0_0
                        long      %%0_0_0_3_0_3_0_3_0_3_0_3_0_0_0_0
                        long      %%0_0_3_0_3_0_3_0_3_0_3_0_3_0_0_0
                        long      %%0_0_0_3_0_3_0_3_0_3_0_3_0_3_0_0
                        long      %%0_0_3_0_1_1_1_0_3_1_1_1_3_0_0_0
                        long      %%0_3_0_3_1_1_1_3_0_1_1_1_0_3_0_0
                        long      %%0_0_3_0_1_1_1_0_3_1_1_1_3_0_3_0
                        long      %%0_3_0_3_0_3_0_3_0_3_0_3_0_3_0_0
                        long      %%0_0_3_0_3_0_3_0_3_0_3_0_3_0_0_0
                        long      %%0_0_0_3_0_3_0_3_0_3_0_3_0_3_0_0
                        long      %%0_0_3_0_3_0_3_0_3_0_3_0_3_0_0_0
                        long      %%0_0_0_3_0_3_0_3_0_3_0_3_0_0_0_0
                        long      %%0_0_0_0_3_0_3_0_3_0_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_0_3_0_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_0_3_0_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_0_3_0_3_0_0_0_0_0_0

sprite_bitmap_mask_1    long      %%0_0_0_0_3_0_3_0_3_0_3_0_0_0_0_0
                        long      %%0_0_0_3_0_3_0_3_0_3_0_3_0_0_0_0
                        long      %%0_0_3_0_3_0_3_0_3_0_3_0_3_0_0_0
                        long      %%0_0_0_3_0_3_0_3_0_3_0_3_0_3_0_0
                        long      %%0_0_3_0_3_3_3_0_3_3_3_3_3_0_0_0
                        long      %%0_3_0_3_3_3_3_3_0_3_3_3_0_3_0_0
                        long      %%0_0_3_0_3_3_3_0_3_3_3_3_3_0_3_0
                        long      %%0_3_0_3_0_3_0_3_0_3_0_3_0_3_0_0
                        long      %%0_0_3_0_3_0_3_0_3_0_3_0_3_0_0_0
                        long      %%0_0_0_3_0_3_0_3_0_3_0_3_0_3_0_0
                        long      %%0_0_3_0_3_0_3_0_3_0_3_0_3_0_0_0
                        long      %%0_0_0_3_0_3_0_3_0_3_0_3_0_0_0_0
                        long      %%0_0_0_0_3_0_3_0_3_0_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_0_3_0_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_0_3_0_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_0_3_0_3_0_0_0_0_0_0

sprite_bitmap_2         long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_1_1_1_0_0_1_1_1_0_0_0_0
                        long      %%0_0_0_0_1_1_1_0_0_1_1_1_0_0_0_0
                        long      %%0_0_0_0_1_1_1_0_0_1_1_1_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

sprite_bitmap_mask_2    long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_0_0_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_3_0_0_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_3_0_0_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

sprite_bitmap_3         long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

sprite_bitmap_mask_3    long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

sprite_bitmap_4         long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0             'Gumdrop
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_1_1_3_3_3_3_1_1_3_3_0_0
                        long      %%0_3_3_3_3_1_1_3_3_1_1_3_3_3_3_0
                        long      %%0_3_3_3_3_1_1_3_3_1_1_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_2_2_2_2_3_3_3_3_3_0
                        long      %%0_3_3_2_2_2_1_1_1_1_2_2_2_3_3_0
                        long      %%0_3_2_1_1_1_3_3_3_3_1_1_1_2_3_0
                        long      %%0_2_1_1_3_3_3_3_3_3_3_3_1_1_2_0
                        long      %%0_1_1_0_3_3_0_0_0_0_3_3_0_1_1_0

sprite_bitmap_mask_4    long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_0_3_3_0_0_0_0_3_3_0_3_3_0

sprite_bitmap_5         long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_1_1_3_3_3_3_1_1_3_3_0_0
                        long      %%0_3_3_3_3_1_1_3_3_1_1_3_3_3_3_0
                        long      %%0_3_3_3_3_1_1_3_3_1_1_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_2_2_3_3_3_3_2_2_3_3_3_0
                        long      %%0_3_3_2_1_1_2_3_3_2_1_1_2_3_3_0
                        long      %%0_3_2_1_3_3_1_2_2_1_3_3_1_2_3_0
                        long      %%0_3_1_3_3_3_3_1_1_3_3_3_3_1_3_0
                        long      %%0_1_1_3_0_0_3_3_3_3_0_0_3_1_1_0

sprite_bitmap_mask_5    long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_0_0_3_3_3_3_0_0_3_3_3_0

sprite_bitmap_6         long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_1_1_3_0_0_3_1_0_0_0_0_0
                        long      %%0_0_0_3_3_1_1_3_3_1_1_3_0_0_0_0
                        long      %%0_0_3_3_1_1_3_3_3_1_1_1_3_3_0_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_1_1_3_3_0
                        long      %%0_3_3_3_2_2_3_3_3_3_2_2_3_3_3_0
                        long      %%0_3_2_1_1_1_2_2_2_2_1_1_1_2_3_0
                        long      %%0_0_1_1_3_3_1_1_1_1_3_3_1_1_2_0
                        long      %%0_1_1_3_3_3_3_3_3_3_3_3_3_1_1_0

sprite_bitmap_mask_6    long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_0_0_3_3_0_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0

sprite_bitmap_7         long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_3_3_0_3_0_0_0_0
                        long      %%0_0_3_3_3_3_0_1_1_3_3_3_3_0_0_0
                        long      %%3_3_3_3_1_3_3_3_3_1_1_1_3_3_3_3

sprite_bitmap_mask_7    long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_3_3_0_3_0_0_0_0
                        long      %%0_0_3_3_3_3_0_3_3_3_3_3_3_0_0_0
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3

sprite_bitmap_8         long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0             'Caterpillar
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_3_3_0_0_0_0_0_0_0_3_3_0
                        long      %%0_0_0_3_3_3_3_0_0_0_0_0_3_3_1_3
                        long      %%0_3_1_3_3_3_3_1_3_0_3_3_1_3_3_0
                        long      %%3_3_3_1_3_3_1_3_3_1_3_3_3_1_3_3
                        long      %%3_3_3_3_0_0_3_3_3_1_3_3_3_0_0_0
                        long      %%0_3_3_0_0_0_0_3_3_0_3_3_0_0_0_0

sprite_bitmap_mask_8    long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_3_3_0_0_0_0_0_0_0_3_3_0
                        long      %%0_0_0_3_3_3_3_0_0_0_0_0_3_3_3_3
                        long      %%0_3_3_3_3_3_3_3_3_0_3_3_3_3_3_0
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_0_0_3_3_3_3_3_3_3_0_0_0
                        long      %%0_3_3_0_0_0_0_3_3_0_3_3_0_0_0_0

sprite_bitmap_9         long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_3_3_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_3_3_3_3_0_0_0
                        long      %%0_0_0_0_0_0_3_3_1_3_3_3_3_1_3_0
                        long      %%0_0_0_0_3_3_1_3_3_1_3_3_1_3_1_3
                        long      %%0_0_0_0_3_3_3_1_3_3_0_0_3_3_3_0
                        long      %%0_0_0_0_0_3_3_0_3_0_0_0_0_3_3_3

sprite_bitmap_mask_9    long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_3_3_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_3_3_3_3_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_3_3_3_3_3_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%0_0_0_0_3_3_3_3_3_3_0_0_3_3_3_0
                        long      %%0_0_0_0_0_3_3_0_3_0_0_0_0_3_3_3

sprite_bitmap_10        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_3_3_0_0_0_0_0_0_0_3_3_0_0_0_0
                        long      %%3_1_3_3_0_0_0_0_0_3_3_3_3_0_0_0
                        long      %%0_3_3_1_3_3_0_3_1_3_3_3_3_1_3_0
                        long      %%3_3_1_3_3_3_1_3_3_1_3_3_1_3_3_3
                        long      %%0_0_0_3_3_3_1_3_3_3_0_0_3_3_3_3
                        long      %%0_0_0_0_3_3_0_3_3_0_0_0_0_3_3_0


sprite_bitmap_mask_10   long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_3_3_0_0_0_0_0_0_0_3_3_0_0_0_0
                        long      %%3_3_3_3_0_0_0_0_0_3_3_3_3_0_0_0
                        long      %%0_3_3_3_3_3_0_3_3_3_3_3_3_3_3_0
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%0_0_0_3_3_3_3_3_3_3_0_0_3_3_3_3
                        long      %%0_0_0_0_3_3_0_3_3_0_0_0_0_3_3_0

sprite_bitmap_11        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_3_3_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_3_3_3_3_0_0_0_0_0_0_0_0_0
                        long      %%0_3_1_3_3_3_3_1_3_3_0_0_0_0_0_0
                        long      %%3_1_3_1_3_3_1_3_3_1_3_3_0_0_0_0
                        long      %%0_3_3_3_0_0_3_3_1_3_3_3_0_0_0_0
                        long      %%3_3_3_0_0_0_0_3_0_3_3_0_0_0_0_0


sprite_bitmap_mask_11   long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_3_3_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_3_3_3_3_0_0_0_0_0_0_0_0_0
                        long      %%0_3_3_3_3_3_3_3_3_3_0_0_0_0_0_0
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_3_3_3_0_0_3_3_3_3_3_3_0_0_0_0
                        long      %%3_3_3_0_0_0_0_3_0_3_3_0_0_0_0_0

sprite_bitmap_12        long      %%0_0_0_0_3_3_0_0_0_0_3_3_0_0_0_0             'Butterfly
                        long      %%0_0_0_3_0_0_3_0_0_3_0_0_3_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_3_3_0_0_3_3_3_3_3_3_0_0_3_3_0
                        long      %%0_3_3_3_0_0_3_3_3_3_0_0_3_3_3_0
                        long      %%3_3_3_3_0_0_0_3_3_0_0_0_3_3_3_3
                        long      %%3_3_3_3_3_0_0_3_3_0_0_3_3_3_3_3
                        long      %%3_2_3_3_3_3_0_3_3_0_3_3_3_3_2_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%0_3_3_2_3_3_0_3_3_0_3_3_2_3_3_0
                        long      %%0_0_0_3_3_3_0_3_3_0_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_0_3_3_0_3_3_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0

sprite_bitmap_mask_12   long      %%0_0_0_0_3_3_0_0_0_0_3_3_0_0_0_0
                        long      %%0_0_0_3_0_0_3_0_0_3_0_0_3_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_3_3_0_0_3_3_3_3_3_3_0_0_3_3_0
                        long      %%0_3_3_3_0_0_3_3_3_3_0_0_3_3_3_0
                        long      %%3_3_3_3_0_0_0_3_3_0_0_0_3_3_3_3
                        long      %%3_3_3_3_3_0_0_3_3_0_0_3_3_3_3_3
                        long      %%3_3_3_3_3_3_0_3_3_0_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%0_3_3_3_3_3_0_3_3_0_3_3_3_3_3_0
                        long      %%0_0_0_3_3_3_0_3_3_0_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_0_3_3_0_3_3_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0

sprite_bitmap_13        long      %%0_0_0_0_0_1_3_0_0_3_1_0_0_0_0_0
                        long      %%0_0_0_0_3_3_1_0_0_1_3_3_0_0_0_0
                        long      %%0_0_0_3_0_1_3_0_0_3_1_0_3_0_0_0
                        long      %%0_0_0_0_3_2_3_0_0_3_2_3_0_0_0_0
                        long      %%0_0_0_0_3_2_1_3_3_1_2_3_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_1_3_3_3_3_1_3_0_0_0_0
                        long      %%0_0_0_0_3_1_1_3_3_1_1_3_0_0_0_0
                        long      %%0_0_0_0_3_1_3_3_3_3_1_3_0_0_0_0
                        long      %%0_0_0_0_3_1_3_3_3_3_1_3_0_0_0_0
                        long      %%0_0_0_0_3_1_3_3_3_3_1_3_0_0_0_0
                        long      %%0_0_0_0_3_1_1_3_3_1_1_3_0_0_0_0
                        long      %%0_0_0_0_0_3_1_3_3_1_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_1_3_3_1_3_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0

sprite_bitmap_mask_13   long      %%0_0_0_0_0_3_3_0_0_3_3_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_0_0_3_3_3_0_0_0_0
                        long      %%0_0_0_3_0_3_3_0_0_3_3_0_3_0_0_0
                        long      %%0_0_0_0_3_3_3_0_0_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0

sprite_bitmap_14        long      %%0_0_0_0_3_3_0_0_0_0_3_3_0_0_0_0
                        long      %%0_0_0_3_0_0_3_0_0_3_0_0_3_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_3_3_0_0_3_3_3_3_3_3_0_0_3_3_0
                        long      %%0_3_3_3_0_0_3_3_3_3_0_0_3_3_3_0
                        long      %%3_3_3_3_0_0_0_3_3_0_0_0_3_3_3_3
                        long      %%3_3_3_3_3_0_0_3_3_0_0_3_3_3_3_3
                        long      %%3_2_3_3_3_3_0_3_3_0_3_3_3_3_2_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%0_3_3_2_3_3_0_3_3_0_3_3_2_3_3_0
                        long      %%0_0_0_3_3_3_0_3_3_0_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_0_3_3_0_3_3_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0

sprite_bitmap_mask_14   long      %%0_0_0_0_3_3_0_0_0_0_3_3_0_0_0_0
                        long      %%0_0_0_3_0_0_3_0_0_3_0_0_3_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_3_3_0_0_3_3_3_3_3_3_0_0_3_3_0
                        long      %%0_3_3_3_0_0_3_3_3_3_0_0_3_3_3_0
                        long      %%3_3_3_3_0_0_0_3_3_0_0_0_3_3_3_3
                        long      %%3_3_3_3_3_0_0_3_3_0_0_3_3_3_3_3
                        long      %%3_3_3_3_3_3_0_3_3_0_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%0_3_3_3_3_3_0_3_3_0_3_3_3_3_3_0
                        long      %%0_0_0_3_3_3_0_3_3_0_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_0_3_3_0_3_3_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0

sprite_bitmap_15        long      %%0_0_0_0_3_3_3_0_0_3_3_3_0_0_0_0
                        long      %%0_0_0_3_0_3_1_3_3_1_3_0_3_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_1_3_3_1_3_0_0_0_0_0
                        long      %%0_0_0_0_3_3_1_3_3_1_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_1_3_3_1_3_3_0_0_0_0
                        long      %%0_0_0_0_3_1_1_3_3_1_1_3_0_0_0_0
                        long      %%0_0_0_0_3_1_0_3_3_0_1_3_0_0_0_0
                        long      %%0_0_0_0_3_1_0_3_3_0_1_3_0_0_0_0
                        long      %%0_0_0_0_3_1_0_3_3_0_1_3_0_0_0_0
                        long      %%0_0_0_0_3_0_0_0_0_0_0_3_0_0_0_0

sprite_bitmap_mask_15   long      %%0_0_0_0_3_3_3_0_0_3_3_3_0_0_0_0
                        long      %%0_0_0_3_0_3_3_3_3_3_3_0_3_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_0_3_3_0_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_0_3_3_0_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_0_3_3_0_3_3_0_0_0_0
                        long      %%0_0_0_0_3_0_0_0_0_0_0_3_0_0_0_0

sprite_bitmap_16        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0             'Fire splash
                        long      %%0_3_0_0_0_0_3_0_0_0_3_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_0_0_0_0_3_0_3_0_0
                        long      %%0_0_0_0_0_0_3_3_0_0_0_3_0_0_0_0
                        long      %%0_0_3_0_0_3_3_3_0_0_0_3_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_0_0_3_3_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_0_3_3_3_0_0_0
                        long      %%0_0_0_3_0_3_2_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_0_3_2_3_3_3_3_2_3_0_0_0
                        long      %%0_0_3_3_3_2_2_3_3_2_3_2_3_3_0_0
                        long      %%0_0_3_3_3_2_2_2_3_2_3_2_3_3_0_0
                        long      %%0_0_3_3_2_2_2_2_2_2_2_2_3_3_3_0
                        long      %%0_3_3_2_2_2_2_2_2_2_2_2_2_3_3_3
                        long      %%3_3_2_2_2_2_2_2_2_2_2_2_2_2_3_3

sprite_bitmap_mask_16   long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_3_0_0_0_0_3_0_0_0_3_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_0_0_0_0_3_0_3_0_0
                        long      %%0_0_0_0_0_0_3_3_0_0_0_3_0_0_0_0
                        long      %%0_0_3_0_0_3_3_3_0_0_0_3_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_0_0_3_3_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_0_3_3_3_0_0_0
                        long      %%0_0_0_3_0_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_0_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3

sprite_bitmap_17        long      %%0_0_0_0_0_0_0_0_0_0_3_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_3_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_0_0_0_0_0_3_0_0
                        long      %%0_0_0_0_0_0_3_3_0_0_0_0_0_3_0_0
                        long      %%0_0_0_0_0_0_3_3_0_0_0_0_0_3_0_0
                        long      %%0_0_0_0_0_0_3_3_3_0_0_3_0_3_0_0
                        long      %%0_0_0_0_0_3_3_3_3_0_0_0_0_3_0_0
                        long      %%0_0_0_0_0_3_3_2_3_0_0_0_0_3_0_0
                        long      %%0_0_3_0_0_3_2_2_3_0_0_0_0_3_3_0
                        long      %%0_0_3_3_0_3_2_2_3_3_0_0_3_3_3_0
                        long      %%0_3_3_3_3_3_2_2_2_3_3_3_3_3_3_0
                        long      %%0_3_2_3_3_3_2_2_2_3_3_3_3_2_3_0
                        long      %%0_3_2_2_3_2_2_2_2_2_3_3_2_2_3_0
                        long      %%3_2_2_2_2_2_2_2_2_2_2_2_2_2_2_3

sprite_bitmap_mask_17   long      %%0_0_0_0_0_0_0_0_0_0_3_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_3_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_0_0_0_0_0_3_0_0
                        long      %%0_0_0_0_0_0_3_3_0_0_0_0_0_3_0_0
                        long      %%0_0_0_0_0_0_3_3_0_0_0_0_0_3_0_0
                        long      %%0_0_0_0_0_0_3_3_3_0_0_3_0_3_0_0
                        long      %%0_0_0_0_0_3_3_3_3_0_0_0_0_3_0_0
                        long      %%0_0_0_0_0_3_3_3_3_0_0_0_0_3_0_0
                        long      %%0_0_3_0_0_3_3_3_3_0_0_0_0_3_3_0
                        long      %%0_0_3_3_0_3_3_3_3_3_0_0_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3

sprite_bitmap_18        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_3_0_0_0_0_0_0_0_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_3_0_0_0_3_0_0_0_0_0_0_0_0_0
                        long      %%0_0_3_0_0_0_0_0_0_0_0_0_0_3_0_0
                        long      %%0_0_3_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_3_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_3_3_0_0_0_0_0_3_0_0_0_0_0_0
                        long      %%0_0_3_3_0_0_0_0_3_3_0_0_0_0_0_0
                        long      %%0_0_3_3_3_0_0_0_3_3_0_0_0_3_0_0
                        long      %%0_0_3_2_3_3_0_3_3_3_0_0_0_3_0_0
                        long      %%0_0_3_2_2_3_3_3_2_3_3_0_3_3_0_0
                        long      %%0_0_3_2_2_2_3_3_2_2_3_3_3_3_0_0
                        long      %%0_3_3_2_2_2_2_3_2_2_3_3_2_3_3_0
                        long      %%0_3_2_2_2_2_2_2_2_2_2_3_2_2_3_0
                        long      %%3_2_2_2_2_2_2_2_2_2_2_2_2_2_2_3

sprite_bitmap_mask_18   long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_3_0_0_0_0_0_0_0_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_3_0_0_0_3_0_0_0_0_0_0_0_0_0
                        long      %%0_0_3_0_0_0_0_0_0_0_0_0_0_3_0_0
                        long      %%0_0_3_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_3_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_3_3_0_0_0_0_0_3_0_0_0_0_0_0
                        long      %%0_0_3_3_0_0_0_0_3_3_0_0_0_0_0_0
                        long      %%0_0_3_3_3_0_0_0_3_3_0_0_0_3_0_0
                        long      %%0_0_3_3_3_3_0_3_3_3_0_0_0_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_0_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3

sprite_bitmap_19        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_3_0
                        long      %%0_0_3_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_3_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_3_0_3_0_0_0_0
                        long      %%0_3_0_0_0_0_0_0_0_0_0_3_0_0_0_0
                        long      %%0_0_0_3_0_0_0_3_0_0_0_3_0_0_0_0
                        long      %%0_0_0_3_0_0_0_3_0_0_0_3_3_0_0_0
                        long      %%0_0_0_3_3_0_0_3_3_0_0_3_3_0_0_0
                        long      %%0_0_0_3_3_3_0_3_3_0_3_3_3_0_0_0
                        long      %%0_0_0_3_2_3_3_3_3_3_3_2_3_0_0_0
                        long      %%0_0_0_3_2_3_3_2_3_3_3_2_3_3_0_0
                        long      %%0_0_3_3_2_3_3_2_3_3_2_2_2_3_0_0
                        long      %%0_0_3_2_2_2_3_2_2_3_2_2_2_3_0_0
                        long      %%0_3_3_2_2_2_2_2_2_2_2_2_2_3_3_0
                        long      %%3_3_2_2_2_2_2_2_2_2_2_2_2_2_3_3

sprite_bitmap_mask_19   long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_3_0
                        long      %%0_0_3_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_3_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_3_0_3_0_0_0_0
                        long      %%0_3_0_0_0_0_0_0_0_0_0_3_0_0_0_0
                        long      %%0_0_0_3_0_0_0_3_0_0_0_3_0_0_0_0
                        long      %%0_0_0_3_0_0_0_3_0_0_0_3_3_0_0_0
                        long      %%0_0_0_3_3_0_0_3_3_0_0_3_3_0_0_0
                        long      %%0_0_0_3_3_3_0_3_3_0_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3

sprite_bitmap_20        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0             'Flower
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0

sprite_bitmap_mask_20   long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0

sprite_bitmap_21        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_0_0_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_1_1_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0

sprite_bitmap_mask_21   long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_0_0_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0

sprite_bitmap_22        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_0_0_3_3_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_3_2_2_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_3_3_1_1_3_3_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_2_2_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0

sprite_bitmap_mask_22   long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_0_0_3_3_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0

sprite_bitmap_23        long      %%0_0_0_0_3_3_3_0_0_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_2_2_2_2_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_2_1_1_2_3_3_0_0_0_0
                        long      %%0_0_0_3_3_2_1_1_1_1_2_3_3_0_0_0
                        long      %%0_0_0_3_3_3_2_1_1_2_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_2_2_2_2_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0

sprite_bitmap_mask_23   long      %%0_0_0_0_3_3_3_0_0_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_3_3_0_0_0_0_0_0_0

sprite_bitmap_24        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0             'Door
                        long      %%0_0_0_3_3_1_3_1_3_1_3_1_3_0_0_0
                        long      %%0_0_0_3_1_1_1_3_1_1_1_3_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_3_1_3_1_3_0_0_0
                        long      %%0_0_0_3_1_3_1_1_1_3_1_1_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_3_1_3_1_3_0_0_0
                        long      %%0_0_0_3_1_1_1_3_1_1_1_3_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_3_1_3_1_3_0_0_0
                        long      %%0_0_0_3_1_3_1_1_1_3_1_1_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_3_1_3_1_3_0_0_0
                        long      %%0_0_0_3_1_1_1_3_1_1_1_3_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_3_1_3_1_3_0_0_0
                        long      %%0_0_0_3_1_3_1_1_1_3_1_1_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_3_1_3_1_3_0_0_0
                        long      %%0_0_0_3_1_1_1_3_1_1_1_3_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_3_1_3_1_3_0_0_0

sprite_bitmap_mask_24   long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0

sprite_bitmap_25        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_1_3_1_3_1_2_2_3_0_0_0
                        long      %%0_0_0_3_1_3_1_1_1_3_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_3_1_2_2_3_0_0_0
                        long      %%0_0_0_3_1_1_1_3_1_1_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_3_1_2_2_3_0_0_0
                        long      %%0_0_0_3_1_3_1_1_1_3_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_3_1_2_2_3_0_0_0
                        long      %%0_0_0_3_1_1_1_3_1_1_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_3_1_2_2_3_0_0_0
                        long      %%0_0_0_3_1_3_1_1_1_3_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_3_1_2_2_3_0_0_0
                        long      %%0_0_0_3_1_1_1_3_1_1_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_3_1_2_2_3_0_0_0
                        long      %%0_0_0_3_1_3_1_1_1_3_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_3_1_2_2_3_0_0_0

sprite_bitmap_mask_25   long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0

sprite_bitmap_26        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_1_3_1_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_1_1_1_3_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_1_3_1_1_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_1_1_1_3_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_1_3_1_1_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_1_1_1_3_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_1_3_1_1_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_1_1_1_3_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_3_1_2_2_2_2_3_0_0_0

sprite_bitmap_mask_26   long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0

sprite_bitmap_27        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_1_2_2_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_1_3_2_2_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_2_2_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_1_1_2_2_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_2_2_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_1_3_2_2_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_2_2_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_1_1_2_2_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_2_2_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_1_3_2_2_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_2_2_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_1_1_2_2_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_2_2_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_1_3_2_2_2_2_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_2_2_2_2_2_2_3_0_0_0

sprite_bitmap_mask_27   long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0

sprite_bitmap_28        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0             'Eye
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_2_2_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_2_2_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_2_3_0_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_1_1_1_1_1_1_1_1_1_1_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0

sprite_bitmap_mask_28   long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0

sprite_bitmap_29        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_2_2_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_1_1_1_1_1_2_3_0_0_0
                        long      %%0_0_3_3_1_1_1_1_1_1_1_1_3_3_0_0
                        long      %%0_0_3_1_1_1_1_1_1_1_3_3_1_3_0_0
                        long      %%0_0_3_1_1_1_1_1_1_3_3_3_3_3_0_0
                        long      %%0_0_3_1_1_1_1_1_1_3_3_3_3_3_0_0
                        long      %%0_0_3_1_1_1_1_1_1_1_3_3_1_3_0_0
                        long      %%0_0_3_3_1_1_1_1_1_1_1_1_3_3_0_0
                        long      %%0_0_0_3_3_1_1_1_1_1_1_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0

sprite_bitmap_mask_29   long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0

sprite_bitmap_30        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_2_2_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_1_1_1_1_1_2_3_0_0_0
                        long      %%0_0_3_3_1_1_1_1_1_1_1_1_3_3_0_0
                        long      %%0_0_3_1_1_1_1_3_3_1_1_1_1_3_0_0
                        long      %%0_0_3_1_1_1_3_3_3_3_1_1_1_3_0_0
                        long      %%0_0_3_1_1_1_3_3_3_3_1_1_1_3_0_0
                        long      %%0_0_3_1_1_1_1_3_3_1_1_1_1_3_0_0
                        long      %%0_0_3_3_1_1_1_1_1_1_1_1_3_3_0_0
                        long      %%0_0_0_3_3_1_1_1_1_1_1_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0

sprite_bitmap_mask_30   long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0

sprite_bitmap_31        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_2_2_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_2_2_3_0_0_0
                        long      %%0_0_0_3_3_1_1_1_1_1_1_2_3_0_0_0
                        long      %%0_0_3_3_1_1_1_1_1_1_1_1_3_3_0_0
                        long      %%0_0_3_1_3_3_1_1_1_1_1_1_1_3_0_0
                        long      %%0_0_3_3_3_3_3_1_1_1_1_1_1_3_0_0
                        long      %%0_0_3_3_3_3_3_1_1_1_1_1_1_3_0_0
                        long      %%0_0_3_1_3_3_1_1_1_1_1_1_1_3_0_0
                        long      %%0_0_3_3_1_1_1_1_1_1_1_1_3_3_0_0
                        long      %%0_0_0_3_3_1_1_1_1_1_1_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0

sprite_bitmap_mask_31   long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_0_3_3_3_3_0_0_0_0_0_0

sprite_bitmap_mask_63   long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_3_3_3_3_3_3_3_3_3_3_3_3_3_3_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_3_3_3_3_3_3_3_3_3_3_3_3_0_0
                        long      %%0_0_0_3_3_3_3_3_3_3_3_3_3_0_0_0
                        long      %%0_0_0_0_3_3_3_3_3_3_3_3_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_3_3_3_3_3_3_0_0_0_0_0

sprite_bitmap_64        long      %%0_0_0_0_2_2_2_2_2_2_2_2_0_0_0_0
                        long      %%0_0_0_2_2_2_2_1_3_2_2_2_2_0_0_0
                        long      %%0_0_2_2_2_2_1_3_1_3_2_2_2_2_0_0
                        long      %%0_2_2_2_2_2_3_1_3_1_2_2_2_2_2_0
                        long      %%2_2_2_2_2_3_1_3_1_3_1_2_2_2_2_2
                        long      %%1_1_1_1_2_2_2_2_2_2_2_2_3_3_3_3
                        long      %%0_1_1_1_1_2_2_2_2_2_2_3_3_3_3_0
                        long      %%0_0_1_1_1_2_2_2_2_2_2_3_3_3_0_0
                        long      %%0_0_1_1_1_1_2_2_2_2_3_3_3_3_0_0
                        long      %%0_0_0_1_1_1_2_2_2_2_3_3_3_0_0_0
                        long      %%0_0_0_0_1_1_2_2_2_2_3_3_0_0_0_0
                        long      %%0_0_0_0_0_1_1_2_2_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_1_1_2_2_3_3_0_0_0_0_0
                        long      %%0_0_0_0_0_0_1_2_2_3_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_1_3_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

sprite_bitmap_mask_64   long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3
                        long      %%3_3_3_3_3_3_3_3_3_3_3_3_3_3_3_3


sprite_bitmap_65        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0 ' tile 7
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

sprite_bitmap_mask_65   long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0 ' tile 7
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0
                        long      %%0_0_0_0_0_0_0_0_0_0_0_0_0_0_0_0

' /////////////////////////////////////////////////////////////////////////////

'See official Parallax or Hydra documentation for color format

'main palettes

              'Day palettes
palette       long %0000_0_111__1110_1_110__0000_0_100__0000_1_100               'White, cyan, grey, baby blue
              long %0000_0_111__1110_1_110__1110_1_101__0000_0_101               'White, pale cyan, icy cyan, light grey
              long %0000_0_111__1100_1_110__1111_1_100__0000_1_011               'White, light cyan, pale blue, dark blue
              long %0000_0_111__1000_1_101__0110_1_100__0101_1_011               'White, yellow, orange, red
              long %0000_0_111__1001_1_101__1010_1_100__1010_1_011               'White, yellow, light green, dark green
              long %0000_0_111__0000_0_101__0000_0_100__0000_0_011               'White, light grey, grey, dark grey
              long %0000_0_111__0000_0_110__1111_1_100__1101_1_110               'White, bright grey, pale blue, light cyan
              long %1000_0_111__0000_0_101__0000_0_100__0000_0_010               'White, light grey, grey, black

              'Night Palettes
              long %1001_1_000__0000_1_100__0000_0_011__0000_0_010               'Hyper blue, light grey, dark gray, black
              long %0000_0_111__1000_1_101__0101_1_100__0000_0_010               'White, yellow, pale red, black
              long %0000_0_101__1100_1_101__1111_1_011__0000_0_010               'Light grey, light cyan, pale blue, black
              long %0000_0_011__1000_1_100__0111_1_011__0000_0_010               'Grey, pale yellow, black, dark red
              long %0000_0_101__0000_1_100__1100_1_011__1111_1_011               'light gray, yellow, light green, pale blue
              long %0000_0_011__1000_0_111__0011_1_100__0000_0_010               'Dark grey, white, magenta, black
              long %1110_1_101__1010_0_011__0000_0_100__0000_0_010               'Pale cyan, dark grey, grey, black
              long %1110_1_000__1010_0_100__0000_0_011__0000_0_010               'Hyper red, grey, dark grey, black

              'System palettes, not used in worlds
              long %1000_1_101__1101_1_011__0011_1_110__0000_0_111               '16 (highlight)
              long %1000_1_000__1111_1_000__0011_1_000__0000_0_010               '17 (intro)
              long %1000_1_000__1111_1_000__0000_0_111__0000_0_111               '18 (intro)
              long %0000_0_010__0000_0_010__0000_0_010__1111_1_100               '19 (loading)

              'Glitch palettes (placeholders)
              long %0000_1_100__0000_1_100__0000_1_100__0000_1_100               '20
              long %0000_1_100__0000_1_100__0000_1_100__0000_1_100
              long %0000_1_100__0000_1_100__0000_1_100__0000_1_100
              long %0000_1_100__0000_1_100__0000_1_100__0000_1_100
              long %0000_1_100__0000_1_100__0000_1_100__0000_1_100
              long %0000_1_100__0000_1_100__0000_1_100__0000_1_100
              long %0000_1_100__0000_1_100__0000_1_100__0000_1_100
              long %0000_1_100__0000_1_100__0000_1_100__0000_1_100               '27
              long %0000_1_100__0000_1_100__0000_1_100__0000_1_100
              long %0000_1_100__0000_1_100__0000_1_100__0000_1_100
              long %0000_1_100__0000_1_100__0000_1_100__0000_1_100
              long %0000_1_100__0000_1_100__0000_1_100__0000_1_100
              long %0000_1_100__0000_1_100__0000_1_100__0000_1_100
              long %0000_1_100__0000_1_100__0000_1_100__0000_1_100
              long %0000_1_100__0000_1_100__0000_1_100__0000_1_100
              long %0000_1_100__0000_1_100__0000_1_100__0000_1_100               '35
              long %0000_1_100__0000_1_100__0000_1_100__0000_1_100               '36 (highlight)


'Used in TileEdit method
edit_array              byte 176,177,178,179,180,181,182,183,184,185
                        byte 160,161,162,163,164,165,166,167,168,169
                        byte 144,145,146,147,148,149,150,151,152,153
                        byte 128,129,130,131,132,133,134,135,136,137
                        byte 112,113,114,115,116,117,118,119,120,121
                        byte 96,97,98,99,100,101,102,103,104,105
                        byte 80,81,82,83,84,85,86,87,88,89
                        byte 64,65,66,67,68,69,70,71,72,73
                        byte 48,49,50,51,52,53,54,55,56,57
                        byte 32,33,34,35,36,37,38,39,40,41
                        byte 16,17,18,19,20,21,22,23,24,25
                        byte 0,1,2,3,4,5,6,7,8,9

